(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    265553,       4953]
NotebookOptionsPosition[    259458,       4853]
NotebookOutlinePosition[    259897,       4872]
CellTagsIndexPosition[    259854,       4869]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Temperatur f\[ODoubleDot]r k\[ADoubleDot]rnfusion", \
"Subsection"]], "Text",
 CellChangeTimes->{{3.741417724427335*^9, 3.741417740818915*^9}, {
  3.788331088849042*^9, 
  3.788331089332774*^9}},ExpressionUUID->"4d461007-e9a4-438a-91d1-\
eb977c53216e"],

Cell[TextData[{
 "Det h\[ADoubleDot]r Mathematica-dokumentet ger en skiss av \
utr\[ADoubleDot]kningen av temperaturen och densiteten som kr\[ADoubleDot]vs \
f\[ODoubleDot]r att f\[ARing] ut energi fr\[ARing]n deuterium-tritium-fusion \
i en fusionsreaktor (som ITER), och hur l\[ADoubleDot]nge den m\[ARing]ste \
uppr\[ADoubleDot]tth\[ARing]llas. Det \[ADoubleDot]r en liknande utr\
\[ADoubleDot]kning f\[ODoubleDot]r proton-proton-fusion i solens inre.\n\
(Referens: Kranes bok \[OpenCurlyDoubleQuote]Intro. Nuclear Physics\
\[CloseCurlyDoubleQuote], kap.14.)\n\nF\[ODoubleDot]rsta fr\[ARing]gan \
\[ADoubleDot]r: om tv\[ARing] atomk\[ADoubleDot]rnor kommer n\[ADoubleDot]ra \
varandra, vad \[ADoubleDot]r sannolikheten att de sl\[ARing]s ihop? Den \
beskrivs av \[CloseCurlyDoubleQuote]tv\[ADoubleDot]rsnittsarean\
\[CloseCurlyDoubleQuote] \[Sigma].  (Varf\[ODoubleDot]r \
\[CloseCurlyDoubleQuote]area\[CloseCurlyDoubleQuote]? se min text och video \
om Rutherfords \[Sigma] i k\[ADoubleDot]rnfysik, och sedan i partikelfysik). \
Det enda du beh\[ODoubleDot]ver f\[ODoubleDot]rst\[ARing] h\[ADoubleDot]r \
\[ADoubleDot]r att stort \[CloseCurlyDoubleQuote]tv\[ADoubleDot]rsnitt\
\[CloseCurlyDoubleQuote] \[Sigma]  betyder stor sannolikhet att fusion mellan \
tv\[ARing] atomk\[ADoubleDot]rnor intr\[ADoubleDot]ffar.\n\n\
Tv\[ADoubleDot]rsnittsarean \[Sigma] \[ADoubleDot]r (t.ex. enligt Rutherford) \
proportionell mot 1/Er d\[ADoubleDot]r Er \[ADoubleDot]r reaktionsenergin ( = \
2 deuteron-energier, varav det mesta \[ADoubleDot]r viloenergi, vid de \
relevanta temperaturerna). Det \[ADoubleDot]r i sin tur proportionellt mot \
1/v^2, eftersom r\[ODoubleDot]relseenergi = 1/2 mv^2 (om hastigheterna \
\[ADoubleDot]r tillr\[ADoubleDot]ckligt l\[ARing]ga f\[ODoubleDot]r att f\
\[ODoubleDot]rsumma relativitetsteori).\n\nF\[ODoubleDot]r l\[ARing]g energi \
spelar effekter fr\[ARing]n kvantfysik ocks\[ARing] in: kvanttunnling ger en \
s.k. ",
 StyleBox["Gamow-faktor",
  FontWeight->"Bold"],
 " e^(-2G) i \[Sigma] som till\[ARing]ter reaktionen att ske \[ADoubleDot]ven \
strax under den klassiskt till\[ARing]tna energin. H\[ADoubleDot]r \
\[ADoubleDot]r formlerna ur Kranes bok:"
}], "Text",
 CellChangeTimes->{{3.741418800648292*^9, 3.7414188337842207`*^9}, {
  3.741423696085328*^9, 3.741423721680564*^9}, {3.741424138344631*^9, 
  3.741424220660129*^9}, {3.741440682039505*^9, 3.7414407835811243`*^9}, {
  3.741534896110896*^9, 3.7415349066868763`*^9}, {3.7417893497225323`*^9, 
  3.741789482528365*^9}, {3.741845663453693*^9, 3.7418460453474283`*^9}, {
  3.741846088416436*^9, 3.741846164928557*^9}, {3.741846208475917*^9, 
  3.741846306978006*^9}, {3.741871095261619*^9, 3.7418712015484324`*^9}, {
  3.742037840765985*^9, 3.742037892854006*^9}, {3.78833110503977*^9, 
  3.7883312112688427`*^9}, {3.7883312459282093`*^9, 
  3.7883313106769114`*^9}},ExpressionUUID->"8d59f7de-516a-46aa-8d76-\
cb7dd31698a8"],

Cell[BoxData[{
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vE", " ", "=", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"2", " ", 
     RowBox[{"Er", "/", "m"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c1", "/", 
       RowBox[{"v", "^", "2"}]}], " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "GKrane"}], "]"}]}], ")"}], " ", "/.", " ", 
    RowBox[{"v", " ", "\[Rule]", "vE"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GKrane", " ", "=", "  ", 
   RowBox[{
    RowBox[{"kC", " ", 
     RowBox[{"e", "^", "2"}], " ", "\[Pi]", " ", "Za", " ", 
     RowBox[{"ZX", " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"hbar", " ", "v"}], ")"}]}]}], " ", "/.", " ", 
    RowBox[{"v", " ", "\[Rule]", "vE"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.741418803245535*^9, 3.741418803379362*^9}, {
   3.741418839822586*^9, 3.741418910514595*^9}, 3.7414237259804*^9, {
   3.7414244998651133`*^9, 3.741424529006263*^9}, {3.7414246549919233`*^9, 
   3.741424679123198*^9}, {3.741429400680242*^9, 3.741429413160355*^9}, 
   3.7414296991135674`*^9, {3.741440587483411*^9, 3.741440591319216*^9}, {
   3.741447153995634*^9, 3.74144716728719*^9}, {3.7414472035455093`*^9, 
   3.741447204132818*^9}, 3.741539750999558*^9, 3.7415398177727613`*^9, {
   3.741539902133719*^9, 3.741539926847294*^9}, 3.7415400075220413`*^9, {
   3.741583795512253*^9, 3.7415837972403507`*^9}, {3.74158404464686*^9, 
   3.741584050860652*^9}, 3.7418463350699053`*^9, 3.741871186560692*^9, {
   3.7418723138348227`*^9, 3.74187231713726*^9}, {3.788067803599217*^9, 
   3.788067804320326*^9}},ExpressionUUID->"5bfde129-298c-47ee-8fa9-\
d6dd4858e203"],

Cell["\<\
Farten v \[ADoubleDot]r relativa farten, och massan \[ADoubleDot]r reducerade \
massan (m/2 om det \[ADoubleDot]r tv\[ARing] likadana partiklar, t.ex. \
protoner eller deuteriumk\[ADoubleDot]rnor. Faktorn 1/2 kommer i vanlig \
mekanik fr\[ARing]n att s\[ADoubleDot]tta origo i en av partiklarna och r\
\[ADoubleDot]kna med relativ hastighet). 

(Kommentar: Tv\[ADoubleDot]rsnittsarean \[Sigma] \[ADoubleDot]r dessutom \
proportionell mot en korrektionsfaktor S(E) som beror p\[ARing] \
k\[ADoubleDot]rnfysik-detaljer. Korrektionsfaktorn varierar l\[ARing]ngsamt \
med energi, se t.ex. forskningsartikeln arXiv:astro-ph/9805121 \
f\[ODoubleDot]r exempel i proton-proton-fusion om du vill se ett exempel, men \
h\[ADoubleDot]r g\[ODoubleDot]r vi approximationen S(E) = konstant s\[ARing] \
du beh\[ODoubleDot]ver inte oroa dig f\[ODoubleDot]r det nu.)

Naturkonstanter och massor (Mathematica vet dem ocks\[ARing], se Quantity):\
\>", "Text",
 CellChangeTimes->{{3.741423628874528*^9, 3.741423651669158*^9}, 
   3.741424190839308*^9, {3.741534521798315*^9, 3.7415345894817743`*^9}, {
   3.741534917758437*^9, 3.741534960954674*^9}, 3.741789513759369*^9, {
   3.741789627848713*^9, 3.7417896282846813`*^9}, {3.7417896644186277`*^9, 
   3.741789668825261*^9}, {3.74184634476066*^9, 3.7418464600176773`*^9}, {
   3.741871207754827*^9, 3.741871260758421*^9}, {3.741871800523665*^9, 
   3.7418718009317017`*^9}, {3.742037909621459*^9, 3.74203794479296*^9}, {
   3.78799075521268*^9, 3.787990781155148*^9}, {3.788331328277117*^9, 
   3.7883314991206427`*^9}},ExpressionUUID->"83ef0966-07ed-450c-a07f-\
a89a947a31d0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vals", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Er", "\[Rule]", " ", 
      RowBox[{"2", " ", "Ed", " ", "keV"}]}], ",", " ", 
     RowBox[{"e", " ", "\[Rule]", " ", 
      RowBox[{"1.602", " ", 
       RowBox[{"10", "^", 
        RowBox[{"(", 
         RowBox[{"-", "19"}], ")"}]}]}]}], ",", " ", 
     RowBox[{"kC", " ", "\[Rule]", " ", 
      RowBox[{"8.99", " ", 
       RowBox[{"10", "^", "9"}]}]}], ",", " ", 
     RowBox[{"Za", " ", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"ZX", " ", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"hbar", " ", "\[Rule]", " ", 
      RowBox[{"1.05", " ", 
       RowBox[{"10", "^", 
        RowBox[{"(", 
         RowBox[{"-", "34"}], ")"}]}]}]}], ",", 
     RowBox[{"m", " ", "->", " ", 
      RowBox[{"3.34", " ", 
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"(", 
          RowBox[{"-", "27"}], ")"}]}], "/", "2"}]}]}], ",", " ", 
     RowBox[{"mp", " ", "\[Rule]", " ", 
      RowBox[{"1.67", " ", 
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"(", 
          RowBox[{"-", "27"}], ")"}]}], "/", "2"}]}]}], ",", 
     RowBox[{"me", " ", "\[Rule]", " ", 
      RowBox[{"9.1", " ", 
       RowBox[{"10", "^", 
        RowBox[{"(", 
         RowBox[{"-", "31"}], ")"}]}]}]}], ",", 
     RowBox[{"c", "\[Rule]", 
      RowBox[{"3", " ", 
       RowBox[{"10", "^", "8"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"keV", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"10", "^", "3"}], " ", "e"}], " ", "/.", " ", "vals"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", "GKrane"}], ")"}], "^", "2"}], " ", "/.", " ", 
  "vals"}]}], "Input",
 CellChangeTimes->{{3.741418917804541*^9, 3.741418956428892*^9}, {
   3.741422786349723*^9, 3.741422792694302*^9}, {3.7414228410283413`*^9, 
   3.74142284153193*^9}, {3.7414228753002996`*^9, 3.741422906960177*^9}, {
   3.7414236084894323`*^9, 3.741423608641836*^9}, {3.741423655390786*^9, 
   3.7414236561896772`*^9}, {3.741424736939253*^9, 3.7414247376162567`*^9}, {
   3.74142480858638*^9, 3.741424828166831*^9}, {3.7414249723591433`*^9, 
   3.7414249843612757`*^9}, 3.741425238138682*^9, {3.7414259869573793`*^9, 
   3.741425987819584*^9}, {3.74142915741755*^9, 3.741429159141864*^9}, {
   3.741430199964572*^9, 3.741430202026231*^9}, {3.741430398184211*^9, 
   3.741430400170844*^9}, {3.7414405983799543`*^9, 3.7414406013575897`*^9}, {
   3.7414471885125847`*^9, 3.741447215970483*^9}, {3.741447837616788*^9, 
   3.741447861580892*^9}, {3.7415346058472357`*^9, 3.7415346119420443`*^9}, {
   3.74153484923882*^9, 3.741534849379155*^9}, {3.741535158882533*^9, 
   3.741535161467494*^9}, {3.7415354387174883`*^9, 3.741535453060343*^9}, {
   3.741538777621718*^9, 3.74153887506365*^9}, {3.74153918344475*^9, 
   3.7415392097950773`*^9}, {3.741539546485437*^9, 3.741539580009672*^9}, {
   3.741539642133925*^9, 3.7415396908333797`*^9}, {3.7415840565167303`*^9, 
   3.741584057354087*^9}, {3.741871343012854*^9, 3.741871343444714*^9}, {
   3.787999378294684*^9, 3.787999381075397*^9}, {3.787999560144903*^9, 
   3.787999623173339*^9}},
 CellLabel->
  "In[416]:=",ExpressionUUID->"7b919e3f-2b33-46cf-9743-bdda4832251e"],

Cell[BoxData[
 FormBox[
  FractionBox["496.757619343156`", "Ed"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7879993817076683`*^9, {3.787999562276204*^9, 3.787999623520158*^9}},
 CellLabel->
  "Out[418]=",ExpressionUUID->"960208ba-efb6-49ba-a30b-e6819b5021b8"]
}, Open  ]],

Cell["\<\
Som en fotnot: t.ex. p\[ARing] Wikipedia ser man det h\[ADoubleDot]r \
uttrycket f\[ODoubleDot]r Gamow-energin (i exemplet m=mp, dvs. protonmassan):\
\
\>", "Text",
 CellChangeTimes->{{3.741539056443112*^9, 3.741539069350338*^9}, {
   3.741539212464066*^9, 3.741539219322925*^9}, {3.74158392925274*^9, 
   3.741583933771227*^9}, {3.7417114779408607`*^9, 3.741711478350692*^9}, {
   3.741789680202248*^9, 3.741789712395347*^9}, {3.74184646827879*^9, 
   3.74184647273845*^9}, 
   3.741871777856134*^9},ExpressionUUID->"7c84d2a5-062c-4036-a723-\
ead94f4f419d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GamowenergiProton", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "mp", " ", 
     RowBox[{"c", "^", "2"}], 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Pi]", " ", "\[Alpha]", " ", "Za", " ", "ZX"}], ")"}], "^", 
       "2"}], "/", "keV"}]}], "  ", "/.", " ", 
    RowBox[{"\[Alpha]", "\[Rule]", 
     RowBox[{"kC", " ", 
      RowBox[{
       RowBox[{"e", "^", "2"}], "/", 
       RowBox[{"(", 
        RowBox[{"hbar", " ", "c"}], ")"}]}]}]}]}], " ", "/.", " ", 
   "vals"}]}]], "Input",
 CellChangeTimes->{{3.741539058285797*^9, 3.741539159371064*^9}, {
   3.741539246077303*^9, 3.741539290930092*^9}, {3.7415393681937523`*^9, 
   3.741539370264002*^9}, 3.74153967011465*^9, {3.741583813382772*^9, 
   3.741583838644704*^9}, 3.7415839108505087`*^9, {3.7415839920545*^9, 
   3.7415840058482437`*^9}, 3.74158403655158*^9, {3.74170687059123*^9, 
   3.741706888901784*^9}, {3.741706967616352*^9, 3.741706969781886*^9}, {
   3.7418713035450497`*^9, 3.741871321137611*^9}, {3.741871886708063*^9, 
   3.741871909265686*^9}, 3.7418720405361433`*^9, {3.741872354333172*^9, 
   3.741872366507718*^9}},
 CellLabel->
  "In[369]:=",ExpressionUUID->"2cd1e7b2-dce9-401a-bf32-d1ad539725ef"],

Cell[BoxData[
 FormBox["496.7576193431561`", TraditionalForm]], "Output",
 CellChangeTimes->{{3.741539126476206*^9, 3.7415391598184633`*^9}, {
   3.7415392488365107`*^9, 3.741539295074792*^9}, 3.7415393708068237`*^9, {
   3.741539617389908*^9, 3.7415396349579763`*^9}, {3.741539670763257*^9, 
   3.7415396943309097`*^9}, {3.7415397429692173`*^9, 3.7415397611045218`*^9}, 
   3.741539939205516*^9, 3.7415399792723913`*^9, 3.741540013962707*^9, 
   3.74154010751473*^9, 3.741540196326473*^9, 3.7415838575355587`*^9, {
   3.741583891488055*^9, 3.741583915057966*^9}, 3.741583948293705*^9, {
   3.741583992695241*^9, 3.741584009192136*^9}, 3.7417067569299*^9, {
   3.741706873889586*^9, 3.741706889289777*^9}, 3.741706970561899*^9, 
   3.741711455743937*^9, 3.7417859219864388`*^9, {3.741871718401843*^9, 
   3.74187176414075*^9}, 3.741871816494817*^9, {3.741871894314169*^9, 
   3.741871909848353*^9}, 3.741872010997328*^9, {3.741872041321271*^9, 
   3.7418720501276627`*^9}, 3.741872324093712*^9, {3.741872357846819*^9, 
   3.7418723775159082`*^9}, 3.7418724191826897`*^9, 3.741872734720108*^9, 
   3.741873789524075*^9, 3.741874221473167*^9, 3.742037949486534*^9, 
   3.787999275358839*^9},
 CellLabel->
  "Out[369]=",ExpressionUUID->"23372146-8b39-42cc-8922-ddad7db9db33"]
}, Open  ]],

Cell[TextData[{
 "St\[ADoubleDot]mmer med ovanst\[ARing]ende (och andra referenser som  t.ex. \
\[LineSeparator]",
 StyleBox["zuserver2.star.ucl.ac.uk/~idh/PHAS2112/Lectures/Current/Part7.pdf ",
  FontSlant->"Italic"],
 "). S\[ARing] Gamowenergin \[ADoubleDot]r n\[ARing]gra hundra keV, medan de \
termiska energier man kan uppn\[ARing] i fusionsreaktor och i solen \
\[ADoubleDot]r n\[ARing]got, eller mycket, l\[ADoubleDot]gre. Det betyder att \
den grova approximationen i kvantfysik av \
\[ODoubleDot]verf\[ODoubleDot]ringsfaktorn ",
 StyleBox["T",
  FontSlant->"Italic"],
 " som en exponentialfunktion \[ADoubleDot]r ganska bra."
}], "Text",
 CellChangeTimes->{{3.741789516602611*^9, 3.741789521672038*^9}, {
  3.741789695351788*^9, 3.7417897474920273`*^9}, {3.741846488590603*^9, 
  3.741846493933502*^9}, {3.741871796061264*^9, 3.741871796970058*^9}, {
  3.787999632162307*^9, 3.78799963669254*^9}, {3.788331543183165*^9, 
  3.7883316549906693`*^9}},ExpressionUUID->"9eeb8bd1-bf61-459d-86cc-\
5e9a6b8ef289"],

Cell["\<\
Tv\[ADoubleDot]rsnittsarean \[Sigma] normerar jag fr\[ARing]n fig.14.1 i Krane,
t.ex. vi kan best\[ADoubleDot]mma att vi skall ha \[Sigma] = 0.04 barn vid \
100 keV (1 barn = 10^(-28)m^2)\
\>", "Text",
 CellChangeTimes->{{3.741423434542324*^9, 3.741423515131558*^9}, {
   3.741424226456045*^9, 3.741424257776642*^9}, {3.741539298946135*^9, 
   3.741539318792344*^9}, {3.741539774488224*^9, 3.7415397966360903`*^9}, {
   3.741539962762661*^9, 3.741539963024572*^9}, {3.741789757318346*^9, 
   3.741789764634191*^9}, {3.74184651854757*^9, 3.741846535390691*^9}, {
   3.741871372125317*^9, 3.741871390491967*^9}, 3.74187183799463*^9, 
   3.788331542198337*^9, 3.7883316059205017`*^9, {3.788331676271591*^9, 
   3.788331686872257*^9}},ExpressionUUID->"ac30f270-c8fc-4262-aab2-\
a77cf2f76e0d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Ednorm", " ", "=", " ", "100"}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]norm", " ", "=", " ", 
   RowBox[{
    RowBox[{"\[Sigma]", " ", "/.", " ", "vals"}], "  ", "/.", " ", 
    RowBox[{"{", " ", 
     RowBox[{"Ed", " ", "\[Rule]", " ", "Ednorm"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1val", " ", "=", " ", 
   RowBox[{"First", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"\[Sigma]norm", " ", "\[Equal]", " ", 
       RowBox[{"4", " ", 
        RowBox[{"10", "^", 
         RowBox[{"(", 
          RowBox[{"-", "2"}], ")"}]}]}]}], ",", "c1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]val", " ", "=", 
   RowBox[{
    RowBox[{"\[Sigma]", "    ", "/.", " ", "c1val"}], " ", "/.", "  ", 
    "vals"}]}], "   "}], "\[IndentingNewLine]", 
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]val", "/.", " ", "vals"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.069"}], "+", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "GKrane"}], "]"}]}], "/.", " ", "vals"}]}], 
    "}"}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"Ed", ",", "10", ",", "100"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Sigma]val", "/.", " ", "vals"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.5"}], "+", 
         RowBox[{"c1", "/", 
          RowBox[{"v", "^", "2"}]}]}], " ", "/.", "c1val"}], "  ", "/.", " ", 
       
       RowBox[{"v", " ", "\[Rule]", "vE"}]}], "/.", " ", "vals"}]}], "}"}], 
   "  ", ",", 
   RowBox[{"{", 
    RowBox[{"Ed", ",", "10", ",", "100"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.741418965282103*^9, 3.7414189694177732`*^9}, {
   3.741419033952323*^9, 3.741419048558961*^9}, {3.741423358273972*^9, 
   3.7414233663772078`*^9}, {3.741423406275893*^9, 3.741423410055169*^9}, {
   3.741423521479566*^9, 3.741423610642499*^9}, {3.741423665913759*^9, 
   3.741423682389613*^9}, {3.7414237367143383`*^9, 3.741423877709559*^9}, {
   3.741423937871161*^9, 3.741423993831895*^9}, {3.7414246910174923`*^9, 
   3.7414248915112047`*^9}, {3.7414249474561987`*^9, 
   3.7414250058366013`*^9}, {3.7414250389333353`*^9, 3.741425128109888*^9}, {
   3.741425213832616*^9, 3.741425244524722*^9}, {3.74142527541059*^9, 
   3.741425276334187*^9}, 3.74142536648807*^9, {3.741425422150889*^9, 
   3.741425435178368*^9}, {3.741425481735022*^9, 3.7414255110103197`*^9}, {
   3.741429184108597*^9, 3.741429199038452*^9}, {3.74143025382577*^9, 
   3.741430254476315*^9}, {3.741440606856514*^9, 3.741440612573969*^9}, 
   3.741451967102669*^9, {3.7414520422567244`*^9, 3.7414520499965878`*^9}, {
   3.741452122315506*^9, 3.741452129473061*^9}, {3.74145218711379*^9, 
   3.741452189221179*^9}, {3.741534697447914*^9, 3.7415347003286037`*^9}, {
   3.741535199507648*^9, 3.74153520030858*^9}, {3.7415399604104652`*^9, 
   3.741539969554871*^9}, {3.7415400285317163`*^9, 3.741540039941476*^9}, {
   3.741583964405099*^9, 3.741583968075698*^9}, {3.787999848960537*^9, 
   3.7879999039810658`*^9}, {3.787999942257882*^9, 3.7879999810007467`*^9}, {
   3.7880000114125834`*^9, 3.78800009876258*^9}, {3.78800021315418*^9, 
   3.788000216126894*^9}, 3.788000253076367*^9, {3.7880003206671658`*^9, 
   3.788000373698639*^9}, {3.788000427532383*^9, 3.7880004421226254`*^9}, {
   3.788064623759441*^9, 3.788064630351296*^9}, {3.788064665015959*^9, 
   3.788064668753214*^9}},
 CellLabel->
  "In[654]:=",ExpressionUUID->"49bd51c1-2a0d-4a17-9b3c-5f244dbe8005"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"37.155074728413624`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox["22.2880600174882`", 
       SqrtBox["Ed"]]}]]}], "Ed"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.741418969766901*^9, 3.7414190498283577`*^9, {3.741422900460745*^9, 
   3.741422910295508*^9}, 3.7414233670890827`*^9, {3.7414235614710073`*^9, 
   3.741423603057395*^9}, {3.7414236600305967`*^9, 3.741423666581615*^9}, 
   3.74142373764321*^9, {3.741423776096469*^9, 3.741423866800877*^9}, {
   3.741423940722622*^9, 3.7414239943509703`*^9}, {3.741424726762117*^9, 
   3.7414247833214893`*^9}, {3.741424830821432*^9, 3.7414249262703123`*^9}, {
   3.7414249569696198`*^9, 3.74142500654331*^9}, {3.741425039657844*^9, 
   3.741425147338286*^9}, {3.74142522136481*^9, 3.741425245029768*^9}, {
   3.741425355658791*^9, 3.741425367567453*^9}, {3.7414254229063473`*^9, 
   3.7414254355334682`*^9}, {3.741425483729162*^9, 3.7414255114898233`*^9}, 
   3.741426009309828*^9, {3.741429191950429*^9, 3.7414291995592403`*^9}, 
   3.7414292834685507`*^9, 3.741429388999461*^9, 3.741429524349086*^9, 
   3.74142971816113*^9, 3.741430218415992*^9, 3.7414302548803377`*^9, 
   3.741440464925296*^9, 3.741441665653164*^9, {3.741447193013279*^9, 
   3.741447222015542*^9}, 3.7414519680859118`*^9, 3.741452051044306*^9, 
   3.741452130185424*^9, 3.741452189841465*^9, 3.741534624270722*^9, {
   3.741534659527776*^9, 3.741534701064825*^9}, 3.7415348586181087`*^9, 
   3.741535146158394*^9, {3.741535183543028*^9, 3.741535201176283*^9}, 
   3.741535397833436*^9, 3.741535442482522*^9, {3.7415399717086353`*^9, 
   3.741539979354808*^9}, {3.741540016608767*^9, 3.7415400407822247`*^9}, 
   3.741540076349543*^9, 3.741540107599222*^9, 3.741540196410117*^9, 
   3.7415838579423723`*^9, {3.741583891801525*^9, 3.741583915511073*^9}, {
   3.741583948712208*^9, 3.7415839692030067`*^9}, 3.741584009653273*^9, 
   3.7417067690769253`*^9, {3.7417071183556337`*^9, 3.741707131323627*^9}, {
   3.741707164922143*^9, 3.7417072337647743`*^9}, 3.741707336692585*^9, 
   3.741711455909301*^9, 3.7417859221494617`*^9, {3.7418717185511847`*^9, 
   3.7418717355344067`*^9}, 3.741871840711413*^9, 3.741871912661565*^9, 
   3.7418720119510803`*^9, 3.741872054446059*^9, 3.741872327506505*^9, 
   3.741872377595437*^9, 3.74187241924829*^9, 3.741872735346653*^9, 
   3.741873792489973*^9, 3.7418742250196857`*^9, 3.742037952283249*^9, 
   3.787999275423706*^9, {3.787999874665227*^9, 3.7879999043007298`*^9}, {
   3.7879999482620173`*^9, 3.78799997256043*^9}, {3.788000029883206*^9, 
   3.788000099321535*^9}, {3.7880002137792273`*^9, 3.788000217835005*^9}, 
   3.788000253996634*^9, {3.7880003226662483`*^9, 3.788000374316802*^9}, {
   3.78800043018719*^9, 3.788000442626136*^9}, {3.788064624409474*^9, 
   3.788064630603256*^9}, {3.788064665632257*^9, 3.788064670271902*^9}},
 CellLabel->
  "Out[657]=",ExpressionUUID->"3c1f34bd-ee7a-42e3-97e7-3224d3f8b302"],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVznk81AkfB/DZZDMzrjnleMjsIEc0DcZVfZUr5D5+OVpHqIhK1lFaQkuE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        "]]},
      Annotation[#, "Charting`Private`Tag$132161#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVjnk0lXkYx2W5eK90d2tlyVZRk0Go8cgaTvK+F2+loluMUhyyVBQmo+yi
mlSnJB0HNbYUGedJM00qoUJE2aOVEq6teeeP3/n98XnO5/PV3RNK7pOVkZER
M+//P0JWPqRtxAuMYzsrKw6rYWaH+zh+8oIvKcJ3gVvVcKbPx210zgt6fvK4
wxoVoatDjPezBS8I1fZaaO4W4dnrF/wrZUgotYv1q28R4dqg7qg4eRKUBHGf
WTUiDPwYUMBVIYGqVptcmyrC1smQOWstEmaGHg5vthBhbKdyyoI2CfkVuRq1
q0RoWHdD7cEyEnYbpyyz1xPh0YTedR56JNwcn/qWvUSEeiri4F0mJPg1z9Sb
fxBiuK5te6IVCYr5K6uNbgiR76Fc9oQiwbTxTnydsRDrzW5szPJm+q/sHkl0
hfgr1+GJ2JeESBf2BXVNIda1xw73bCchwC+eV8wW4t6AMe2xABKipyw2BX0R
YFVUx2lBGAkx1s6pK2oE6J1fKNmZRgLP0/lDgViAeda5sy4ZzN4TJh2mWwTY
25qYsy6LBE6XulODiwD3y/o/UMwlIYg9oEPYCjBeoqlfcZGE1clynjw9AZYa
ZPazSkhINNLUfD/OR9nimICyRhJynlqNzp/no+umIGneExKcWhS088/wMb3L
OzupiYSDvxzLcU/nozrb/P72VhKaTs7LVify0Szkk45CJ+MPCeh4c5CP28z2
9G4bIWGZ/Fx7mBMfyyrcd8spUqBvSxoYSXlIPr19pEmJgs9vw4bfTvBwYmh5
7nmCgmG7MY/LYzxcrzHxaJUqBZuXh/cbjPDw/olL68RCCrbVLugc7ODhc49P
CoX6FKxXDu58Us3Db8MZpc5AAbcrRT8zhoeWWs+lp49QINvFLrnM4qFbuFjD
/RgFBZV/HibleLizsX29ShwFUff3yRMyPDwZ/To6I56CgLpaSYKUiy9eDH4/
k0xB+L0d17M+cjEsbWr84lkKrFQDJaYvuFgyr/3+ZjkF7qq8HIdrXNTpDepq
HaXALq66QduFi80fbeVrPlDwauch3ZWOXDwuXWJ29RMFSxdq66ztudjNu5tw
aJyCNNfWi7ttufiHk5IJW0pBrE/D1X/WcJFTUhTtqCSG5mZPuWl1LspEjQru
GIqh81JSWN9HDvaxD3hekohBz+7bF/M8DjZlbJG4tInh2cC8sheHg9kxV9iR
W72hegPZytFegjX1P6SSRm8QRgxPim1UUcUPks1tfMD2VOS/NnGL0dL/c1FS
lQ+8Se6cpR+oYOq92OC7hr6wSMlb8nqFCjpGaIaVnvMFVsPqDYfPsvFltgFb
n0OD5Mci/0AFNmYqcp2OJtCQVJR2RXKKwNqvPTsO/0aDRlsLuP5O4GBPcfih
JBoEG+3jTU8SaFPleHXPaRp8F7u9kp5guH/MrFs2DcUJiQMXoglcX/u2XCuf
hqrQm1pTgQT2h9xa9hfS8DRY9rG+M4Eq9DGLOw00GNuppms5Emjl4OpR/jcN
+10GB/ibCEzT6D9S+IiGmfFKd9YvDH8obEtvoeH1AXJ23ILhy+NSd/XSwLnS
fW7QgMBqwu0a3U+DpZFe+JA+gX3fRTXkIA3x7QHdw7oEWj4tG3YeoWF6qMDv
w1KGxwzarxmjoch2sfyskNmzt5w2+UrD7Za5LTIC5t7zeKj+BA0dY7mGLB7T
M1C/rDbN7PfIO8pXZXqcoUruDA2yLyMnNVUY32z5Y/YcDYWx7fN6BON7d7xP
YYGGbGlE1iolxvfcffrHD6Znwbr1M4vA/wBnYmGr
        "]]},
      Annotation[#, "Charting`Private`Tag$132161#2"]& ]}, {}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{10, -5.863962946080427},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None},
   PlotRange->{{10, 100}, {-5.863962946080427, -3.21887582696948}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->FrontEndValueCache[{Automatic, 
      Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-5.298317366548036, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.605170185988091, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-3.912023005428146, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.020\"", 0.02, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-6.214608098422191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-5.809142990314028, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-5.521460917862246, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-5.115995809754082, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.961845129926823, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.710530701645918, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.199705077879927, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3.506557897319982, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.995732273553991, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.659260036932778, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.741418969766901*^9, 3.7414190498283577`*^9, {3.741422900460745*^9, 
   3.741422910295508*^9}, 3.7414233670890827`*^9, {3.7414235614710073`*^9, 
   3.741423603057395*^9}, {3.7414236600305967`*^9, 3.741423666581615*^9}, 
   3.74142373764321*^9, {3.741423776096469*^9, 3.741423866800877*^9}, {
   3.741423940722622*^9, 3.7414239943509703`*^9}, {3.741424726762117*^9, 
   3.7414247833214893`*^9}, {3.741424830821432*^9, 3.7414249262703123`*^9}, {
   3.7414249569696198`*^9, 3.74142500654331*^9}, {3.741425039657844*^9, 
   3.741425147338286*^9}, {3.74142522136481*^9, 3.741425245029768*^9}, {
   3.741425355658791*^9, 3.741425367567453*^9}, {3.7414254229063473`*^9, 
   3.7414254355334682`*^9}, {3.741425483729162*^9, 3.7414255114898233`*^9}, 
   3.741426009309828*^9, {3.741429191950429*^9, 3.7414291995592403`*^9}, 
   3.7414292834685507`*^9, 3.741429388999461*^9, 3.741429524349086*^9, 
   3.74142971816113*^9, 3.741430218415992*^9, 3.7414302548803377`*^9, 
   3.741440464925296*^9, 3.741441665653164*^9, {3.741447193013279*^9, 
   3.741447222015542*^9}, 3.7414519680859118`*^9, 3.741452051044306*^9, 
   3.741452130185424*^9, 3.741452189841465*^9, 3.741534624270722*^9, {
   3.741534659527776*^9, 3.741534701064825*^9}, 3.7415348586181087`*^9, 
   3.741535146158394*^9, {3.741535183543028*^9, 3.741535201176283*^9}, 
   3.741535397833436*^9, 3.741535442482522*^9, {3.7415399717086353`*^9, 
   3.741539979354808*^9}, {3.741540016608767*^9, 3.7415400407822247`*^9}, 
   3.741540076349543*^9, 3.741540107599222*^9, 3.741540196410117*^9, 
   3.7415838579423723`*^9, {3.741583891801525*^9, 3.741583915511073*^9}, {
   3.741583948712208*^9, 3.7415839692030067`*^9}, 3.741584009653273*^9, 
   3.7417067690769253`*^9, {3.7417071183556337`*^9, 3.741707131323627*^9}, {
   3.741707164922143*^9, 3.7417072337647743`*^9}, 3.741707336692585*^9, 
   3.741711455909301*^9, 3.7417859221494617`*^9, {3.7418717185511847`*^9, 
   3.7418717355344067`*^9}, 3.741871840711413*^9, 3.741871912661565*^9, 
   3.7418720119510803`*^9, 3.741872054446059*^9, 3.741872327506505*^9, 
   3.741872377595437*^9, 3.74187241924829*^9, 3.741872735346653*^9, 
   3.741873792489973*^9, 3.7418742250196857`*^9, 3.742037952283249*^9, 
   3.787999275423706*^9, {3.787999874665227*^9, 3.7879999043007298`*^9}, {
   3.7879999482620173`*^9, 3.78799997256043*^9}, {3.788000029883206*^9, 
   3.788000099321535*^9}, {3.7880002137792273`*^9, 3.788000217835005*^9}, 
   3.788000253996634*^9, {3.7880003226662483`*^9, 3.788000374316802*^9}, {
   3.78800043018719*^9, 3.788000442626136*^9}, {3.788064624409474*^9, 
   3.788064630603256*^9}, {3.788064665632257*^9, 3.788064670387959*^9}},
 CellLabel->
  "Out[658]=",ExpressionUUID->"68b5d49e-7bbc-42e7-a3be-f4099cace500"],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVznk81AkfB/DZZDMzrjnleMjsIEc0DcZVfZUr5D5+OVpHqIhK1lFaQkuE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        "]]},
      Annotation[#, "Charting`Private`Tag$132326#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVU3k81PkfHuU+hmEQitZOrRUl9yTNuyhy7ff7sWIViZypJKKSlEhIqxrr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        "]]},
      Annotation[#, "Charting`Private`Tag$132326#2"]& ]}, {}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{10, -8.185271365177146},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None},
   PlotRange->{{10, 100}, {-8.185271365177146, 1.1679849783620762`}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->FrontEndValueCache[{Automatic, 
      Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-6.907755278982137, 
        FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.605170185988091, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox["1", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8.517193191416238, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-8.111728083308073, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7.824046010856292, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7.600902459542082, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7.418580902748128, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7.264430222920869, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-7.013115794639964, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-6.214608098422191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-5.809142990314028, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-5.521460917862246, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-5.298317366548036, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-5.115995809754082, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.961845129926823, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.710530701645918, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3.912023005428146, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3.506557897319982, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.995732273553991, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.659260036932778, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.916290731874155, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.791759469228055, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.302585092994046, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.995732273553991, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.741418969766901*^9, 3.7414190498283577`*^9, {3.741422900460745*^9, 
   3.741422910295508*^9}, 3.7414233670890827`*^9, {3.7414235614710073`*^9, 
   3.741423603057395*^9}, {3.7414236600305967`*^9, 3.741423666581615*^9}, 
   3.74142373764321*^9, {3.741423776096469*^9, 3.741423866800877*^9}, {
   3.741423940722622*^9, 3.7414239943509703`*^9}, {3.741424726762117*^9, 
   3.7414247833214893`*^9}, {3.741424830821432*^9, 3.7414249262703123`*^9}, {
   3.7414249569696198`*^9, 3.74142500654331*^9}, {3.741425039657844*^9, 
   3.741425147338286*^9}, {3.74142522136481*^9, 3.741425245029768*^9}, {
   3.741425355658791*^9, 3.741425367567453*^9}, {3.7414254229063473`*^9, 
   3.7414254355334682`*^9}, {3.741425483729162*^9, 3.7414255114898233`*^9}, 
   3.741426009309828*^9, {3.741429191950429*^9, 3.7414291995592403`*^9}, 
   3.7414292834685507`*^9, 3.741429388999461*^9, 3.741429524349086*^9, 
   3.74142971816113*^9, 3.741430218415992*^9, 3.7414302548803377`*^9, 
   3.741440464925296*^9, 3.741441665653164*^9, {3.741447193013279*^9, 
   3.741447222015542*^9}, 3.7414519680859118`*^9, 3.741452051044306*^9, 
   3.741452130185424*^9, 3.741452189841465*^9, 3.741534624270722*^9, {
   3.741534659527776*^9, 3.741534701064825*^9}, 3.7415348586181087`*^9, 
   3.741535146158394*^9, {3.741535183543028*^9, 3.741535201176283*^9}, 
   3.741535397833436*^9, 3.741535442482522*^9, {3.7415399717086353`*^9, 
   3.741539979354808*^9}, {3.741540016608767*^9, 3.7415400407822247`*^9}, 
   3.741540076349543*^9, 3.741540107599222*^9, 3.741540196410117*^9, 
   3.7415838579423723`*^9, {3.741583891801525*^9, 3.741583915511073*^9}, {
   3.741583948712208*^9, 3.7415839692030067`*^9}, 3.741584009653273*^9, 
   3.7417067690769253`*^9, {3.7417071183556337`*^9, 3.741707131323627*^9}, {
   3.741707164922143*^9, 3.7417072337647743`*^9}, 3.741707336692585*^9, 
   3.741711455909301*^9, 3.7417859221494617`*^9, {3.7418717185511847`*^9, 
   3.7418717355344067`*^9}, 3.741871840711413*^9, 3.741871912661565*^9, 
   3.7418720119510803`*^9, 3.741872054446059*^9, 3.741872327506505*^9, 
   3.741872377595437*^9, 3.74187241924829*^9, 3.741872735346653*^9, 
   3.741873792489973*^9, 3.7418742250196857`*^9, 3.742037952283249*^9, 
   3.787999275423706*^9, {3.787999874665227*^9, 3.7879999043007298`*^9}, {
   3.7879999482620173`*^9, 3.78799997256043*^9}, {3.788000029883206*^9, 
   3.788000099321535*^9}, {3.7880002137792273`*^9, 3.788000217835005*^9}, 
   3.788000253996634*^9, {3.7880003226662483`*^9, 3.788000374316802*^9}, {
   3.78800043018719*^9, 3.788000442626136*^9}, {3.788064624409474*^9, 
   3.788064630603256*^9}, {3.788064665632257*^9, 3.7880646705184717`*^9}},
 CellLabel->
  "Out[659]=",ExpressionUUID->"28c97024-1b10-4902-870a-db0c62d8a678"]
}, Open  ]],

Cell["\<\
V\[ADoubleDot]rdena skall vara ungef\[ADoubleDot]r: \[Sigma](20) = 0.004 \
barn, \[Sigma](50) = 0.01 barn, \[Sigma](100) = 0.04 barn.  
Fr\[ARing]n ovanst\[ARing]ende funktion \[Sigma](E) f\[ARing]r vi\
\>", "Text",
 CellChangeTimes->{{3.7415347038985786`*^9, 3.741534762477138*^9}, {
  3.7415348134228888`*^9, 3.741534844315051*^9}, {3.741539948575528*^9, 
  3.741539955098785*^9}, {3.741789771964576*^9, 3.741789775117777*^9}, {
  3.741871403548471*^9, 3.741871421853009*^9}, {3.788331769111887*^9, 
  3.788331774247366*^9}},ExpressionUUID->"29851d8d-41fe-4985-a22a-\
2c597ddedba6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Sigma]val", " ", "/.", " ", 
  RowBox[{"Ed", " ", "\[Rule]", " ", 
   RowBox[{"{", 
    RowBox[{"20", ",", "50", ",", "100"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.741451978324095*^9, 3.741451988750367*^9}, {
  3.7415352116274433`*^9, 3.741535220765486*^9}, {3.74154009429303*^9, 
  3.741540094664578*^9}},
 CellLabel->
  "In[375]:=",ExpressionUUID->"7ac00232-0ab4-44c5-b6e5-1c36e951dbb5"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0.01272236718092468`", ",", "0.03177961227817859`", ",", "0.04`"}], "}"}],
   TraditionalForm]], "Output",
 CellChangeTimes->{
  3.741451991342682*^9, 3.741452216143784*^9, 3.741534624790605*^9, {
   3.74153465969587*^9, 3.741534680112473*^9}, 3.7415351463741617`*^9, 
   3.741535221244183*^9, 3.741535397967857*^9, 3.741535442704649*^9, 
   3.74153997955897*^9, {3.7415400953334837`*^9, 3.741540107786665*^9}, 
   3.741540196575754*^9, 3.74158385867035*^9, {3.741583892271834*^9, 
   3.741583916142846*^9}, 3.741583949480631*^9, 3.741584010371245*^9, 
   3.741706776043537*^9, {3.7417071395908813`*^9, 3.741707236464347*^9}, 
   3.7417073403008738`*^9, 3.741711456089376*^9, 3.741785922333029*^9, {
   3.741871718751224*^9, 3.74187173575019*^9}, 3.7418720177143383`*^9, 
   3.741872332778368*^9, 3.7418723778262987`*^9, 3.7418724194822817`*^9, 
   3.7418727357253103`*^9, 3.741873796627839*^9, 3.7420379557123737`*^9, 
   3.7879992758390827`*^9},
 CellLabel->
  "Out[375]=",ExpressionUUID->"3e2c5c39-d4c2-40f8-9118-aa2433c6f24f"]
}, Open  ]],

Cell[TextData[{
 "Vi ser \[Sigma](20) = 0.012 barn ist\[ADoubleDot]llet f\[ODoubleDot]r 0.004 \
barn, faktor 3 fel. Hade vi tagit med S(E) som omn\[ADoubleDot]ndes ovan kan \
vi modellera b\[ADoubleDot]ttre att \[Sigma](E) skall sjunka snabbare f\
\[ODoubleDot]r l\[ARing]g energi, h\[ADoubleDot]r f\[ARing]r vi \
n\[ODoubleDot]ja oss som det \[ADoubleDot]r, med r\[ADoubleDot]tt \
storleksordning. \n\nNu \[ADoubleDot]r det s\[ARing] att \
atomk\[ADoubleDot]rnorna i ett fusionskraftverk (eller i solen) inte alla har \
samma energi. Det vi p\[ARing] sin h\[ODoubleDot]jd vet \[ADoubleDot]r att \
det finns visst m\[ARing]nga som har en viss energi E f\[ODoubleDot]r en viss \
temperatur T. Mer precist \[ADoubleDot]r energierna f\[ODoubleDot]rdelade \
enligt Maxwell-f\[ODoubleDot]rdelningen, som vi beskriver p\[ARing] en kurs i \
termodynamik (jfr. ",
 StyleBox["tp.hotell.kau.se/marcus/notes",
  FontSlant->"Italic"],
 ").\n\nVi vill r\[ADoubleDot]kna ut den s.k. ",
 StyleBox["reaktiviteten",
  FontWeight->"Bold"],
 " < \[Sigma]  v >, d\[ADoubleDot]r  < .. > betyder medelv\[ADoubleDot]rde. \
\[CapitalADoubleDot]r du inte s\[ARing] intresserad av detaljer fr\[ARing]n \
termofysik kan du skippa ned till slutkl\[ADoubleDot]mmen: \
utr\[ADoubleDot]kningen av \[CloseCurlyDoubleQuote]\[Sigma]vmedel\
\[CloseCurlyDoubleQuote] en bit ner. \nH\[ADoubleDot]r vill vi byta variabler \
 fr\[ARing]n v till E i integralen, som ger en faktor \
\[CloseCurlyDoubleQuote]jac\[CloseCurlyDoubleQuote]\[NonBreakingSpace](\
Jacobian): dv = jac dE"
}], "Text",
 CellChangeTimes->{{3.741417780032653*^9, 3.741417787172097*^9}, {
   3.741418265718354*^9, 3.741418281789109*^9}, 3.7414185759859257`*^9, {
   3.741418611960308*^9, 3.74141869376066*^9}, 3.7414188079708776`*^9, {
   3.7414190550623293`*^9, 3.7414190566169853`*^9}, {3.741424278234188*^9, 
   3.7414242784541187`*^9}, 3.741425536198045*^9, {3.741425692799952*^9, 
   3.741425724797892*^9}, {3.7415356039624233`*^9, 3.741535630300213*^9}, {
   3.741711500325432*^9, 3.741711505408908*^9}, {3.7417897785928993`*^9, 
   3.741789790439519*^9}, {3.7418465502790003`*^9, 3.741846659934716*^9}, {
   3.741846702946097*^9, 3.741846988193481*^9}, {3.741871437567609*^9, 
   3.741871568438683*^9}, {3.741874019474964*^9, 3.74187405509937*^9}, {
   3.788331776749282*^9, 
   3.788331823512875*^9}},ExpressionUUID->"9bf349d6-5cc3-4c0d-99cb-\
a3937742fea2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"jac", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"vE", ",", "Er"}], "]"}], ",", 
    RowBox[{"Assumptions", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"m", ">", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.741425604876346*^9, 3.741425629388348*^9}, {
   3.741425768172288*^9, 3.7414257810956583`*^9}, {3.741429532295999*^9, 
   3.741429532751367*^9}, {3.741440640558262*^9, 3.741440640628924*^9}, 
   3.741441672707316*^9},
 CellLabel->
  "In[376]:=",ExpressionUUID->"a767461a-2c74-4386-8009-ab60987f141d"],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    SqrtBox["2"], " ", 
    SqrtBox[
     RowBox[{"Er", " ", "m"}]]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.741425625096739*^9, 3.741425629911483*^9}, {
   3.741425772342319*^9, 3.7414257857100887`*^9}, 3.741426014689768*^9, 
   3.741429291699297*^9, 3.741429393919121*^9, 3.741429533456987*^9, 
   3.741429721770034*^9, 3.741430313385912*^9, 3.741440465244248*^9, 
   3.741441673839746*^9, 3.741452219994368*^9, 3.741534624873904*^9, {
   3.741534659762171*^9, 3.741534680183145*^9}, 3.741535146441464*^9, 
   3.741535398050881*^9, 3.7415354427714663`*^9, 3.741539979620325*^9, 
   3.7415401078528214`*^9, 3.741540196663824*^9, 3.741583858733919*^9, {
   3.741583892336855*^9, 3.741583916204135*^9}, 3.741583949539113*^9, 
   3.741584010476017*^9, 3.7417072506195383`*^9, 3.741711456155792*^9, 
   3.741785922398325*^9, {3.741871718834034*^9, 3.741871736298006*^9}, 
   3.741872017818656*^9, 3.741872378378584*^9, 3.7418724195653267`*^9, 
   3.741872735790656*^9, 3.741873803362344*^9, 3.7418742326076937`*^9, 
   3.742037958845759*^9, 3.787999275915189*^9},
 CellLabel->
  "Out[376]=",ExpressionUUID->"956f49ac-3ddf-466f-b4a6-c390d4ad2f83"]
}, Open  ]],

Cell["\<\
Massan tar ut sig i energidistributionen:
(st\[ARing]r ocks\[ARing] p\[ARing] Wikipediasidan f\[ODoubleDot]r \
Maxwell-distribution):\
\>", "Text",
 CellChangeTimes->{{3.741425746361445*^9, 3.741425755738681*^9}, {
  3.7415350796234703`*^9, 3.741535105655863*^9}, {3.74184666385151*^9, 
  3.741846679430559*^9}},ExpressionUUID->"76f2740b-dc9f-48b9-99c1-\
930466d869c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fMaxwell", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", " ", "/", " ", 
         RowBox[{"(", 
          RowBox[{"2", " ", "\[Pi]", " ", "kBT"}], ")"}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"3", "/", "2"}], ")"}]}], " ", "4", " ", "\[Pi]", " ", 
      RowBox[{"v", "^", "2"}], " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "m"}], " ", 
        RowBox[{
         RowBox[{"v", "^", "2"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", "kBT"}], ")"}]}]}], "]"}], " ", "jac"}], " ", "/.",
      " ", 
     RowBox[{"v", " ", "\[Rule]", "vE"}]}], ",", 
    RowBox[{"Assumptions", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"m", ">", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellLabel->
  "In[377]:=",ExpressionUUID->"1fe05d76-8095-4074-9fb9-f380c272d74b"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"2", " ", 
    SqrtBox["Er"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", "kBT"], ")"}], 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox["Er", "kBT"]}]]}], 
   SqrtBox["\[Pi]"]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7414299722558613`*^9, 3.74143031575486*^9, 3.74143040803596*^9, 
   3.741440465327311*^9, 3.741441676774069*^9, 3.741441746730816*^9, 
   3.741452229095183*^9, 3.74145227218333*^9, 3.74153462494153*^9, {
   3.741534659832287*^9, 3.741534680248122*^9}, 3.741535146508692*^9, 
   3.7415353981145773`*^9, 3.741535442838018*^9, 3.741539979688712*^9, 
   3.741540107917562*^9, 3.741540196746715*^9, 3.741583858816373*^9, {
   3.741583892436492*^9, 3.7415839162876053`*^9}, 3.741583952666813*^9, 
   3.741584010609429*^9, 3.741707253701077*^9, 3.7417114562228727`*^9, 
   3.741785922465745*^9, {3.741871718900464*^9, 3.741871736528174*^9}, 
   3.741872017905768*^9, 3.741872378613323*^9, 3.741872419649029*^9, 
   3.741872738740135*^9, 3.741873806580474*^9, 3.7418742344577847`*^9, 
   3.742037961537033*^9, 3.7879992759786873`*^9},
 CellLabel->
  "Out[377]=",ExpressionUUID->"d465dd1b-1d52-499f-9b17-1797e1501bd5"]
}, Open  ]],

Cell["\<\
Nu stoppar vi i tal, och n\[ADoubleDot]r vi byter enhet, gl\[ODoubleDot]m \
inte att
dEr = 2 keV dEd, och kolla att arean under f\[ODoubleDot]rdelningsfunktionen \
\[ADoubleDot]r 1 (100%)\
\>", "Text",
 CellChangeTimes->{{3.741429974343203*^9, 3.7414300131881933`*^9}, {
  3.741452255778392*^9, 3.7414522668753853`*^9}, {3.788331834042997*^9, 
  3.788331849973269*^9}},ExpressionUUID->"3c19d77e-2c04-4c97-867e-\
a4c63d9d89a7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fMaxwellval", " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", "keV", " ", "fMaxwell"}], " ", "/.", " ", 
     RowBox[{"kBT", "\[Rule]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"5", ",", "10", ",", "20", ",", "50", ",", "100"}], "}"}], 
       " ", "keV"}]}]}], "/.", " ", "vals"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"fMaxwellval", ",", 
   RowBox[{"{", 
    RowBox[{"Ed", ",", "0", ",", "50"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "50"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.2"}], "}"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Edcutoff", " ", "=", " ", "50000"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"normcheck", " ", "=", " ", 
  RowBox[{"NIntegrate", "[", " ", 
   RowBox[{
    RowBox[{"fMaxwellval", "[", 
     RowBox[{"[", "5", "]"}], "]"}], " ", ",", 
    RowBox[{"{", 
     RowBox[{"Ed", ",", "0", ",", "Edcutoff"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.741418569211494*^9, 3.741418569399839*^9}, {
   3.7414187570678377`*^9, 3.741418785914603*^9}, {3.741422761465097*^9, 
   3.741422782691818*^9}, {3.741422930432186*^9, 3.741422963328804*^9}, {
   3.741423056692266*^9, 3.741423199870007*^9}, {3.741423259554051*^9, 
   3.7414233086636257`*^9}, {3.741423613648099*^9, 3.7414236175942373`*^9}, 
   3.741425543328912*^9, {3.741425575520192*^9, 3.7414255758541822`*^9}, {
   3.7414256374317408`*^9, 3.741425677546771*^9}, {3.741425807619053*^9, 
   3.741425825788973*^9}, 3.741425902065422*^9, {3.7414260175239897`*^9, 
   3.7414261614783783`*^9}, {3.741426196483992*^9, 3.741426202951461*^9}, {
   3.741426254403348*^9, 3.7414262723447437`*^9}, {3.74142637072017*^9, 
   3.741426373982176*^9}, {3.741429254410942*^9, 3.741429258430553*^9}, {
   3.741429327271833*^9, 3.7414293356894913`*^9}, {3.741429422008418*^9, 
   3.741429438884796*^9}, 3.74142988539126*^9, 3.74142992188743*^9, {
   3.741429969111053*^9, 3.741429978306732*^9}, {3.7414303602164097`*^9, 
   3.741430365441802*^9}, {3.74143041234618*^9, 3.741430428463093*^9}, {
   3.741430543837813*^9, 3.741430544188265*^9}, {3.741440651118484*^9, 
   3.7414406559528008`*^9}, 3.7414417237692204`*^9, {3.741441765288145*^9, 
   3.741441786176244*^9}, {3.741442391473577*^9, 3.741442414512689*^9}, {
   3.7414427103820353`*^9, 3.741442736533318*^9}, {3.741442767697665*^9, 
   3.741442767786368*^9}, {3.741442863037517*^9, 3.741442903220396*^9}, {
   3.741447161641844*^9, 3.74144716323988*^9}, {3.741447231226574*^9, 
   3.741447242256143*^9}, {3.741449884600657*^9, 3.741449911918166*^9}, 
   3.741449946828949*^9, {3.741450131593145*^9, 3.741450206707296*^9}, {
   3.741450717303417*^9, 3.741450745537013*^9}, {3.7415346563600817`*^9, 
   3.74153467704775*^9}, {3.7415401910836477`*^9, 3.741540192135531*^9}, {
   3.7417117924869127`*^9, 3.741711806927834*^9}, {3.741711850644433*^9, 
   3.741711896971346*^9}, {3.741785916049911*^9, 3.7417859165653877`*^9}, {
   3.741871586235176*^9, 3.7418715870451107`*^9}},
 CellLabel->
  "In[378]:=",ExpressionUUID->"f7e0b38b-b4cc-414a-a025-5c265f48cb22"],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVV3c4F94bRTKiZSfKXtk7476vrZRkzyiKQkYUsopCQ5IQZSaSMjKKyPZJ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        "]]},
      Annotation[#, "Charting`Private`Tag$108257#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnc4Ff4Xx11do0L2VooyMr/2PMe+URIaVnZWlJkVQqWUlZESImUk272I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        "]]},
      Annotation[#, "Charting`Private`Tag$108257#2"]& ], 
     TagBox[
      {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVl3c8Vv0bx5GZzX1bCUWKPEbkiei6onJrqIxsiYysjAoZIZsQuZE970MZ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        "]]},
      Annotation[#, "Charting`Private`Tag$108257#3"]& ], 
     TagBox[
      {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k4VV8XB3AJKfySikgyuxeJSoNorYw3RSVlSklCkTkZ45rn4R5JkSFE
FEqGZFaUkKRUGgyVNBnKHN79/nWez3P2Pc++++z13etIWDsbnWFnY2MzW8LG
9v+rZPx8drrY3T2pr5z6YzcO7qngpm88bx8PbY9j73w1MIIGr6Icmn0G2Jmd
Hi75aAbU9s/H+eLygOlTzxIsOAnNyq52XPbFcLf+znEFHWvwW7tYuZhZCkf2
ivdxnLOBZJbOnn+xFTD95sjbA2a28CSmizFhVwd+MQUsveazMBrCO+RV0ADL
o2++UDdyAP+mYvpUZhO8a2p6yfvEEZJxsuhPbAvse1s5ZuPvDFIBV8dcQ56C
/bBxVJmVC5TUqG8b9XkG+hwHsw7+c4GnasEPfto9h1xDtoHXkm5QqL76kmpx
J6T7bGE8K3KDsV6bDI+CF+CvUZ7tvN0dLolwD4xnvgSn3GCahJoHXLliaDcS
2wMGFe1WHiKe8HF7ZoRS5BvQLHhAS4n2BOnXY7fOh7wFlezy34xZTyhZc/nn
D59e2DC25vnbzovQmtjr+s3uEyiGOKe8OuMNESnJTymVPvhXbmuU0uwNivZg
vrW4D9willtVyviA27JEX7eCfiiLrRQ49skHFnS21Y5mDsLVpT4FxXv9YF2T
j9av2CH4yj356FD7JXjIkuqO4fkGs8flNsuIBMAJ6zYbxchvMHOcI5nXNgBy
loiFOYQMQ/J7nkWluQBQwYYnwz4/4EWS96ey2EDQr1lm+NVuBEYUZg6KpzFB
ZdF6QnB0BHwk59XF65gQI36yQ0p9FHIMlDc09TPBw7rqgvGjUVgdlLV9ViYI
tL+6PCrrHoPfQnXtNgVBMPDrwymviT+QdFLnfkFOMLyOiy5L2PUX/Gzvypc2
BkPr5l3Lb/n/BYlmrk9efcFwzzWp5C3nBPSF/W7D9SHAnNBfVBOcBAvBd4yB
2BAQn69Im98+DbFuoxkG9qGwJv3M6FrfafjkWe6VHxQK3LBaW6luGsQlCmQ6
00JhJNDpxwm9GTiTrM4e2RkKtRwyavUms8AuMtZ/XzUMLHlZPUFe/+B1Ge1H
+FQYtPNtX85hyYYvC46ETh2PgK79Aikdfmx4bemO4VKXCHgT+Vv2ahob3m75
UGYUEgGfOfO0ld6z4fMrm2t3FkbAv3mhQFOLJXhzKL+kaCoC5H/PTN42Y0dX
KnpHQHQkRHTUfD56jAMPFRjrnc6Mgjjea+7inhzoLIxnfpZEQZK+J/uPyxzI
pX/J72RDFGQ0K4kHvuLAyy/uH+QYiILy2gyLAmNOvB0p6WYgGQ1fiphdC0Zc
GJ7pNM6eEQ2a8Tr1eQe58YRl4Bx3VAwE6t+/1eXEjbuNd5q/vRIDtZxS1Hws
N25cUi58NTcG1PzYbI+0ceMfw8JNQ/UxsPXsQ55FxnLUbqp9UD8ZA9JaKibH
NFeg7tKDnwJPxgLXlOhvDlVeDD1o6TsgEwfa96J7NhvzIm+u1GCnShwEnZ+t
N3fnxWo6rfyuRhwsDPZQJXd58WK78Ij+0TiY6mTtOq7EhyUd1W8/BMfBtwLu
0FK5//B4gIpF8sc4OLN5lk+Fjx+d3tCVnkfFw4He8Nx1Yvw4k8/jvDI5HraF
r9Vg28yPP50iDTSz4oHjk7Lj80P8uKuBphxYEQ834uxazyfx4+ry26knBuPh
06/usIL1q/COgOi8uWgCmN0uXpSSF8DdjO6lUucTAE01rvDsFsDOImXeBdcE
oHE8U/qzXwANWqedX3omwLTFV8vG8wJ4oqze9nxgAiTzbKi2uiuALcqsNyeo
BHh5Lsrr+s7VuHcs941GZQIY0M+MCeqtwddD//UJLyTAbPSFhx+OrcHtqr/v
c7InQv7v0NAc2zXYdcfN6BdnInDcvym8JWwNihY3zxTzJULVnm97DR6vwad9
ll5LNySCrLEDK1hrLabe5BcYUksEtgDXraMgiHyxvuK17olQ1M+cLz8oiFpa
E1YKFxPBQpvV4n9SENfmco8k+SRC+fJSC54AQUzq7me3ZCaCY9LfYNlaQaTn
Wbg0xCXC21sXu4+rC6Hs1zvhH/MT4V63/4WnO9ehd+p4OfMdmW+ojfXAvnVY
lB7sXPchEdK37z84Z74Or8xVHZrpS4SolHX0Tf7r8MSf5rRTQ4lw+njp+4SG
dXjjbm4Lx99EWPP5m5apvjDmY2pFCi8LPP8cERiyEEF4kG3Ev5sFjjlqi4uO
IlhixNz3ToMF1kclfq67JILlx672ZiILDCt+P9bPFMGoSbePUroskPON9C76
LII9fDcqlxxmwRv2ur4L59ejePXLSxttWbBbQL6YI0AUOzPyXaZjWdCxxPxp
e7woRn3+knsogQVWY5GDyZmi+Ht+YCyXxYKQzmEheqMonjB0e6N3hYyPuxVo
wLkBef8LkjubScbz0I2SozfggV1pi1L3yHgO2oRcihgaF3KGRb9kgeBfk5Vj
+WL45t0V0+hXLMgfDKdXPRDDtrDsuIgeFrQ3Dlke6BXD6N5/m3x7yXhmXrOL
2EaMfTvjuXeQBbfmZVMe5GzEuMzi1cbjLLCbY13PNRVH2gKNPfM/CpIMfzZ5
W4ljqtSVk1v5KajP0vluYC+ORrWXSx6tomAdY3r75EVxTJC9uLV/DQVPkiw7
da+Io13Vy6El6ymgK9GWfnsljltcl54YlKXgh1WNvfwRCbysvPWJsgb5/X3B
+AVzCYyt6/AJ3UOB9jKXsi5rCWzfnX3wDVCQdkeS3ddNApk6Dme8NCk4MBue
+ixRAoe1ze1u6FFwhzLqcOyUwP8W3UbSD1Pg3Dy0tdhAEpn1vlJaNmS+eNtB
8Zgk9pd+D/A8QwH/Q5fsWyckcdWUWG+eLQUlxTMCOc6SOLqHLYnjLAXjKTzj
KYmSmKzjqHbzPAWeDptLgl5JYuK4UGG0JwXNX/4MLX6QRLu0C7cyLlIgZFW5
0f+rJJp8j6q960VBpfHe+ItTkuihnrul04eCGY0jTo7CUpgU1nxu8hIFfvwX
FY9ZSqG2GWUyHEZBW9Rum5dnpLA0YIXjp3AKNnCypR1yksKlDVV3XkZQUDsT
wbM/QAq1qB215VEUsA1e+w5ZUsjt4rLLLo6C4LLafPoXKXx8TaTJ7TIFUeZc
MvOO0jhVJLRN4wYFe5R5J4c9pPFNjNrgb+IxToGW137SaN99fGNGNgWmdzec
LYmRxquN8ZpzORTIcKveOX1bGktkVh26kUfWr+y0ausPaVS/9uHk7dsUeESf
5ar4Q+6b2xzRu0OB3Cnnnuw5aUzP3z/YRxzH6+vtzyOD22Sme1cWU2BxmlWj
rCCDeiWN+pZ3KZjkb9C5ck4GmYMOP8rLKCj42iwY4iaDYzLuq9XLKbCsbhty
8ZHBOhP3r3XEj+zeROpHyeD+pO8JTRUUJNaOtM/fksFNJlb8Dx9QoOgodsxm
WAalfrn5OdRQ0LdXWu7wmAxmqU9X9xJTQvLTGjMy+M/GuFy/loLZRtVrQstl
MSBg9LV0HdmvwgYfW2myeO6f4tDTegpOt/jaqtjLIvfM1vmeJgps1GUNJ51l
Ma254NSWRxTY3u1UfXhRFkV2WqVEE9unynDqhMvijFBsgNpjCpycn2eb3pTF
jk/T+6KaKXD57B29oUgW7826He0ldjWTdh8ok8XHn2m7FFrIemp5azo+lkXe
n7tjWoh9hKT6Az7L4uD7yAvjT8h+iWl/ov1TFpv8XU3UnlLgv8SrZPlfWbzM
5iTEJA780RZALZXDmPrwbTytFITVeYrlScrhoJPh1KpnFLDsWi06rOQwQ+u7
xvc2Us/vPbQoezn8kxR0TLydgsuHNyqYusih2FEf06PEKbs9ZvsD5FAvkrG+
mjh9pdjViXQ5nNkWVuzXQUFmyJPAqpty+HeZtmwBcdaMm31AkRz2z3VHvybO
GWzZsbxWDvfkissqPifvt8L1tegHOTy/XrCglfi2omht/2c5lIiVKxghvpPV
nHvzpxyWy1ulr+4k9Ri9/oLyPzmcrx86Y0p8j635+MRSGib9DVXzJi694KJd
xUPDltZhzqvE5Scfr9ZeT5yVGvyKuLLbeY5bioYDQqo7xokf7BMZbJenoZyo
wme+FxRUb3W+Z6JGw7jUWkVN4pp84WuimjT0e5X91Jy4dsMjZv8+Gq4TvWDt
RtywTPiwgxkNV2nZRqUTf81W0n97iob/pOw77hPzoraW3jkaXn7OGHxKvOW9
mXqZGw1jal49/UBs6uWsKuVLw+Lm3qBR4ktrQpUSg2l4XUZuJXsXWa+Sa3KL
0TS0vhjsLEA88u2xcG8amb/JteLNxGtCewX25dLwq8BwgjqxmsQYT8UdGmaK
uO5jEFvVcHHKlNNQhX3urRFxmJnoAquWzLfJUOs48e0JlSm2FhqW1WwNsyHu
StQbdXpOw21VLtkOxNObLIff99Cw/9uzVFfiDa1uA/p9NBwZWOHiSaxpG9Fb
+Y08r3Bc3IfYnj29W3aMhsJFesV+xHHppe1JM+T/N7Wvv0R8X+1pMzs7HW2V
GHb/97vXH+tcVtDx3HVvlj8xm/vfyo8CdORSlE73JZZdueLegfV07LBeHu1F
vL9wY2GVFB0Fd3438yB20VPNoSnSMY4/nMeZOHlQ/3ryNjq+qcvItCeuDrBK
5tCgo1TkH+FTxAPrPePddOhYsXGvlykxd2V0RJ8BHdPydKsNiZWMs5iGx+i4
rrzhqxax8Wi5T/UJOhobOU/vIPaOaXOXt6PjlwmecXnidNqAY4ozHe1jj3SL
Ej96NHWGy4uO3N5LMvmI+eclTQci6Bgp4Dv5g7zf7Vd3Hj6USMeilqqgt8TH
VQ31a6/SMbmPMfeYOO+8t/q1AjqanthyP5W4bXm8KncpHc385ydCiMdzc5Q8
H9Ix9MKk7HniPR+fixu10bE7fr+ZGvErQ1nOFb/J/CxMVz8h+3v2++6Fi5N0
zPvhMJBPLB5+eOrLAh0N5oxuRhA71vkNN6yUx6JrNit1iJcqv2z3VpHHPKtp
77uk/mht35qHdsnjVf7/lkYRG9ov1B3VlMfPgn5hp4ivZdLvqRyRxxhekQA+
YpVVgcnDHvKorH9I34zUexV3D63FTx6fvZ8aUSTWZFN6mBMij7UNXuWLJD+M
R3o/nUySx2a6cv4NYs/2HfTXpfJoUBay6SPJo+rIkYeN4/IodWvVDkWSVzpM
XcPMWXnUcnCVHyd51uF1vc+fXQGD0+T0Kog/2e3n3CWggGf0Cxb2ELPr5hkW
qyjg4mUfD22Shwz2k/2pLgr463TlLzmSpy9myty9vRQwqZ3jfh/JX/MxXi6T
QAW0s20rTCF26KuSF0hQQJ7KVhUu4rhaQY+IYgVkq7DK7SH53u3TwXXhtwIe
rH+WYtxI6u2PhqKhoyLubRj9r6qaAj4Bts5uD0WMrxfrPUxcpdzobuGviG1W
95q/PST166T70D5OEV2Wn1pYTfzkm6F+cIkiRtCl2KzI+aX88aR95V9FFP4p
29FBzkO2p8wcSf9NKLlGOZyniOTjkBbjVugm5N3PMo8g56s5F9fPzXGbsKvu
0EkO4vtaUVs1Mjahoyz34kwhqc9aVqNJwyYMVTp6s/cWBZ2l2X0xnEpokd23
wjuX5HX6Y9GpWCXc/pvRvjGN9FfHFXuOJithzb5nhWGpJP9FqMT76UrY+mfl
y5/XyHokW3G5FSvhH5G6+fKr5HyKmxv52amEeYeqOzWvUGB0SaVpYPVm3P/L
s3sniwKOE9fPdlzdjNp87/2zSD9TGqfW22WkjKHz44/9XSiwTv2Ps+qYMl6O
zghrcaZAIH9AKctcGbVCuer5iV0aooKcrZWxde5gehbpvxT/vqPzuimjqtX7
VTXnSF6a+XrpJCrjx5tpor2kv0uSrl5b+VwZn7ibTJSZkvO0SuPQ9QMqePPv
7eYp0k/WteaOR1pswTsm546tWkLBWb1dNWdNt2JChcmtxnoWpOWrlDmc24Y7
9i4MCl5gQeKfGqbLRVVc0OBLqJJhwdeCC572btvRMsJlarQnER7pslKCgnZg
x7LA3RiYCEsOvhuID9yJWSZDa7sVyPfR3vIlmd678Ki9jodCTwJECE0ZdIWr
YbylDOc97wRwMT/dOBW8GxsLeW8dk0iAfuY2G7isjlq83esCmfGwhrr6LjJL
A339dK2/NMbBTX5575bUPVhtsaznJX8cNLht1JErBNynm3xj/GAspItnimoY
I3pxmr2KSYuBGr9ZNvtOxN6I7Kn8X9EgsX/ZPymTvXj0XGvwUZVouP+cHv22
ey/2+K7cpBscBTHNC8rilpp41uHeh8InkUC5D5+zeq+JjyseaaaLRoLfWrGV
kmZamJET3rfJMwJu0TlbPfq0UL5GvNv4UThw/V0i3HBCG5e7NsgslQiHPOW7
l9KHtLG1YEuHgHsY0K0LDOfP62Aavw1X4LNQ6N334N7RHzqYaxLUILYlFLqy
fTaBuy4+bJ3NEIwPgenSw+qS47oo3GWet3Q2GBYr3crCnPSQcg5Y/uZcMOxX
1tXxm9BD/mro/tgVBC2Wm886uDPw1C75ITVGEAictn94/QIDPzGPd77WCYIT
9ll8nRcZuJfWMOmmFQSTbqvvbfNjYGWr5FzhniCQjpianQ9hYM+pgwPiqkEQ
eK8uJiGZgfv7guUFJYNAbdmhkrIHDJSYcMpW+seEMN5I9m8PyfNeGGztmmHC
i1WNxiK1xLqn2TynmGAvum3mUiMDn9epGNWOM+GKyjpNxjMGDt837z48zIS/
Fn0v371nIFtYg1HIaybgKWFZvk8MtFCcL1PoZkK0rZEX9DOwa+f5Yy9fMEHS
9ZFozhcGdl8eNpRqZ8LhsPwz538zMF/zgFhzExPSovsrMkYZWLhS2sG5gQnf
EkRWdI0zkGOj0sS6OiYEpsYUbZ9i4K/annrHKia0ZT5mOzvDwLe5nuxClUwQ
urlglDrHwA5fXWZDGROsC3fkts8zcNsXXQ3HUiYUlbhMLS4y8Enwxe1Cd5nw
P5IBFVo=
        "]]},
      Annotation[#, "Charting`Private`Tag$108257#4"]& ], 
     TagBox[
      {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13c8lW0YB3CrkJGRipaMQvY4zjkO92XVSVZERiF7b7I5Hq9RQqVUMiLJ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        "]]},
      Annotation[#, "Charting`Private`Tag$108257#5"]& ]}, {}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{0, 50}, {0, 0.2}},
   PlotRangeClipping->True,
   PlotRangePadding->{{0, 0}, {0, 0}},
   Ticks->{Automatic, Automatic}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.741422764331789*^9, 3.7414227779618177`*^9}, {
   3.7414229181914167`*^9, 3.741422963921994*^9}, {3.741423092317842*^9, 
   3.741423120487632*^9}, {3.741423165249045*^9, 3.741423200707313*^9}, {
   3.741423288299974*^9, 3.741423309468473*^9}, 3.741424014548481*^9, 
   3.74142554408046*^9, 3.741425577850135*^9, {3.741425638957539*^9, 
   3.741425678024888*^9}, 3.741425758953185*^9, {3.7414257908105297`*^9, 
   3.7414258274694643`*^9}, 3.7414259027701607`*^9, {3.741426053331191*^9, 
   3.741426092286137*^9}, {3.741426126158071*^9, 3.7414261618726254`*^9}, {
   3.7414261972687597`*^9, 3.741426203397344*^9}, {3.741426254960285*^9, 
   3.741426273547323*^9}, {3.7414263712312393`*^9, 3.741426374852504*^9}, 
   3.741429261342991*^9, {3.741429329158972*^9, 3.74142933612856*^9}, {
   3.741429423235684*^9, 3.7414294394894543`*^9}, 3.741429543397496*^9, 
   3.741429723580621*^9, 3.7414298862536793`*^9, 3.7414299228536453`*^9, 
   3.741430031442815*^9, 3.74143031870823*^9, 3.7414303663959827`*^9, {
   3.7414304132838182`*^9, 3.741430428874652*^9}, 3.741430545303069*^9, 
   3.741440465497672*^9, 3.741441679805583*^9, {3.741441767474659*^9, 
   3.741441788211162*^9}, 3.7414424152571907`*^9, {3.74144271140136*^9, 
   3.741442737005238*^9}, 3.7414427683589573`*^9, {3.7414428797804823`*^9, 
   3.741442904138098*^9}, {3.741447234225637*^9, 3.741447242896728*^9}, {
   3.741449886037738*^9, 3.7414499128505507`*^9}, 3.741449947224042*^9, {
   3.741450155088587*^9, 3.741450207357006*^9}, {3.741450718637865*^9, 
   3.741450745967186*^9}, 3.74145227417661*^9, 3.741534625056912*^9, {
   3.74153466002831*^9, 3.741534680425902*^9}, 3.741535146627439*^9, 
   3.7415353982253523`*^9, 3.74153544295568*^9, 3.741539979819255*^9, 
   3.741540108020445*^9, {3.741540192963395*^9, 3.7415401968664923`*^9}, 
   3.7415838589548283`*^9, {3.741583892557959*^9, 3.741583916608584*^9}, 
   3.741583952919012*^9, 3.741584010728907*^9, 3.741707256843349*^9, 
   3.741711456334631*^9, {3.741711803738618*^9, 3.741711807517337*^9}, 
   3.741711858247666*^9, 3.741711897656233*^9, {3.74178591823311*^9, 
   3.741785922590886*^9}, {3.741871719048424*^9, 3.741871736647058*^9}, 
   3.741872018122903*^9, 3.741872378722527*^9, 3.741872419846932*^9, 
   3.741872738957168*^9, 3.741873808988084*^9, 3.741874238096389*^9, 
   3.742037964475144*^9, 3.787999276139906*^9},
 CellLabel->
  "Out[379]=",ExpressionUUID->"15d51d58-46ab-4c36-a5f6-6b92aae7c2ae"],

Cell[BoxData[
 FormBox["1.0000000000000002`", TraditionalForm]], "Output",
 CellChangeTimes->{{3.741422764331789*^9, 3.7414227779618177`*^9}, {
   3.7414229181914167`*^9, 3.741422963921994*^9}, {3.741423092317842*^9, 
   3.741423120487632*^9}, {3.741423165249045*^9, 3.741423200707313*^9}, {
   3.741423288299974*^9, 3.741423309468473*^9}, 3.741424014548481*^9, 
   3.74142554408046*^9, 3.741425577850135*^9, {3.741425638957539*^9, 
   3.741425678024888*^9}, 3.741425758953185*^9, {3.7414257908105297`*^9, 
   3.7414258274694643`*^9}, 3.7414259027701607`*^9, {3.741426053331191*^9, 
   3.741426092286137*^9}, {3.741426126158071*^9, 3.7414261618726254`*^9}, {
   3.7414261972687597`*^9, 3.741426203397344*^9}, {3.741426254960285*^9, 
   3.741426273547323*^9}, {3.7414263712312393`*^9, 3.741426374852504*^9}, 
   3.741429261342991*^9, {3.741429329158972*^9, 3.74142933612856*^9}, {
   3.741429423235684*^9, 3.7414294394894543`*^9}, 3.741429543397496*^9, 
   3.741429723580621*^9, 3.7414298862536793`*^9, 3.7414299228536453`*^9, 
   3.741430031442815*^9, 3.74143031870823*^9, 3.7414303663959827`*^9, {
   3.7414304132838182`*^9, 3.741430428874652*^9}, 3.741430545303069*^9, 
   3.741440465497672*^9, 3.741441679805583*^9, {3.741441767474659*^9, 
   3.741441788211162*^9}, 3.7414424152571907`*^9, {3.74144271140136*^9, 
   3.741442737005238*^9}, 3.7414427683589573`*^9, {3.7414428797804823`*^9, 
   3.741442904138098*^9}, {3.741447234225637*^9, 3.741447242896728*^9}, {
   3.741449886037738*^9, 3.7414499128505507`*^9}, 3.741449947224042*^9, {
   3.741450155088587*^9, 3.741450207357006*^9}, {3.741450718637865*^9, 
   3.741450745967186*^9}, 3.74145227417661*^9, 3.741534625056912*^9, {
   3.74153466002831*^9, 3.741534680425902*^9}, 3.741535146627439*^9, 
   3.7415353982253523`*^9, 3.74153544295568*^9, 3.741539979819255*^9, 
   3.741540108020445*^9, {3.741540192963395*^9, 3.7415401968664923`*^9}, 
   3.7415838589548283`*^9, {3.741583892557959*^9, 3.741583916608584*^9}, 
   3.741583952919012*^9, 3.741584010728907*^9, 3.741707256843349*^9, 
   3.741711456334631*^9, {3.741711803738618*^9, 3.741711807517337*^9}, 
   3.741711858247666*^9, 3.741711897656233*^9, {3.74178591823311*^9, 
   3.741785922590886*^9}, {3.741871719048424*^9, 3.741871736647058*^9}, 
   3.741872018122903*^9, 3.741872378722527*^9, 3.741872419846932*^9, 
   3.741872738957168*^9, 3.741873808988084*^9, 3.741874238096389*^9, 
   3.742037964475144*^9, 3.787999276310616*^9},
 CellLabel->
  "Out[381]=",ExpressionUUID->"6bd6d82e-ba8f-4efa-9eee-7274247ef427"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"avspeedformel", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Sqrt", "[", " ", 
     RowBox[{"8", " ", 
      RowBox[{"kBT", "/", 
       RowBox[{"(", " ", 
        RowBox[{"\[Pi]", " ", "m"}], ")"}]}]}], "]"}], "/.", " ", 
    RowBox[{"kBT", "\[Rule]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "10", ",", "20", ",", "50", ",", "100"}], "}"}], " ",
       "keV"}]}]}], " ", "/.", " ", "vals"}]}], "\[IndentingNewLine]", 
 RowBox[{"testavspeed", " ", "=", " ", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fMaxwellval", "  ", "vE"}], "/.", " ", "vals"}], ",", 
    RowBox[{"{", 
     RowBox[{"Ed", ",", "0", ",", "Edcutoff"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7418738129032717`*^9, 3.741873813954797*^9}},
 CellLabel->
  "In[382]:=",ExpressionUUID->"87415ee8-81c7-4586-a218-e057438811fb"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "1.1051674354046453`*^6", ",", "1.562942775842341`*^6", ",", 
    "2.2103348708092906`*^6", ",", "3.4948462917256905`*^6", ",", 
    "4.94245902416779`*^6"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.741422764331789*^9, 3.7414227779618177`*^9}, {
   3.7414229181914167`*^9, 3.741422963921994*^9}, {3.741423092317842*^9, 
   3.741423120487632*^9}, {3.741423165249045*^9, 3.741423200707313*^9}, {
   3.741423288299974*^9, 3.741423309468473*^9}, 3.741424014548481*^9, 
   3.74142554408046*^9, 3.741425577850135*^9, {3.741425638957539*^9, 
   3.741425678024888*^9}, 3.741425758953185*^9, {3.7414257908105297`*^9, 
   3.7414258274694643`*^9}, 3.7414259027701607`*^9, {3.741426053331191*^9, 
   3.741426092286137*^9}, {3.741426126158071*^9, 3.7414261618726254`*^9}, {
   3.7414261972687597`*^9, 3.741426203397344*^9}, {3.741426254960285*^9, 
   3.741426273547323*^9}, {3.7414263712312393`*^9, 3.741426374852504*^9}, 
   3.741429261342991*^9, {3.741429329158972*^9, 3.74142933612856*^9}, {
   3.741429423235684*^9, 3.7414294394894543`*^9}, 3.741429543397496*^9, 
   3.741429723580621*^9, 3.7414298862536793`*^9, 3.7414299228536453`*^9, 
   3.741430031442815*^9, 3.74143031870823*^9, 3.7414303663959827`*^9, {
   3.7414304132838182`*^9, 3.741430428874652*^9}, 3.741430545303069*^9, 
   3.741440465497672*^9, 3.741441679805583*^9, {3.741441767474659*^9, 
   3.741441788211162*^9}, 3.7414424152571907`*^9, {3.74144271140136*^9, 
   3.741442737005238*^9}, 3.7414427683589573`*^9, {3.7414428797804823`*^9, 
   3.741442904138098*^9}, {3.741447234225637*^9, 3.741447242896728*^9}, {
   3.741449886037738*^9, 3.7414499128505507`*^9}, 3.741449947224042*^9, {
   3.741450155088587*^9, 3.741450207357006*^9}, {3.741450718637865*^9, 
   3.741450745967186*^9}, 3.74145227417661*^9, 3.741534625056912*^9, {
   3.74153466002831*^9, 3.741534680425902*^9}, 3.741535146627439*^9, 
   3.7415353982253523`*^9, 3.74153544295568*^9, 3.741539979819255*^9, 
   3.741540108020445*^9, {3.741540192963395*^9, 3.7415401968664923`*^9}, 
   3.7415838589548283`*^9, {3.741583892557959*^9, 3.741583916608584*^9}, 
   3.741583952919012*^9, 3.741584010728907*^9, 3.741707256843349*^9, 
   3.741711456334631*^9, {3.741711803738618*^9, 3.741711807517337*^9}, 
   3.741711858247666*^9, 3.741711897656233*^9, {3.74178591823311*^9, 
   3.7417859226367483`*^9}, 3.741871591779469*^9, {3.741871719184846*^9, 
   3.741871736751213*^9}, 3.7418720182177896`*^9, 3.741872378811227*^9, 
   3.74187241998291*^9, 3.741872739071734*^9, 3.7418738153814363`*^9, 
   3.7418742407586203`*^9, 3.742037966838449*^9, 3.78799927648945*^9},
 CellLabel->
  "Out[382]=",ExpressionUUID->"726ce63d-8c51-45b5-b842-51828c2888fd"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "1.1051674354028339`*^6", ",", "1.5629427758423407`*^6", ",", 
    "2.2103348708092896`*^6", ",", "3.4948462917256895`*^6", ",", 
    "4.94245902416779`*^6"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.741422764331789*^9, 3.7414227779618177`*^9}, {
   3.7414229181914167`*^9, 3.741422963921994*^9}, {3.741423092317842*^9, 
   3.741423120487632*^9}, {3.741423165249045*^9, 3.741423200707313*^9}, {
   3.741423288299974*^9, 3.741423309468473*^9}, 3.741424014548481*^9, 
   3.74142554408046*^9, 3.741425577850135*^9, {3.741425638957539*^9, 
   3.741425678024888*^9}, 3.741425758953185*^9, {3.7414257908105297`*^9, 
   3.7414258274694643`*^9}, 3.7414259027701607`*^9, {3.741426053331191*^9, 
   3.741426092286137*^9}, {3.741426126158071*^9, 3.7414261618726254`*^9}, {
   3.7414261972687597`*^9, 3.741426203397344*^9}, {3.741426254960285*^9, 
   3.741426273547323*^9}, {3.7414263712312393`*^9, 3.741426374852504*^9}, 
   3.741429261342991*^9, {3.741429329158972*^9, 3.74142933612856*^9}, {
   3.741429423235684*^9, 3.7414294394894543`*^9}, 3.741429543397496*^9, 
   3.741429723580621*^9, 3.7414298862536793`*^9, 3.7414299228536453`*^9, 
   3.741430031442815*^9, 3.74143031870823*^9, 3.7414303663959827`*^9, {
   3.7414304132838182`*^9, 3.741430428874652*^9}, 3.741430545303069*^9, 
   3.741440465497672*^9, 3.741441679805583*^9, {3.741441767474659*^9, 
   3.741441788211162*^9}, 3.7414424152571907`*^9, {3.74144271140136*^9, 
   3.741442737005238*^9}, 3.7414427683589573`*^9, {3.7414428797804823`*^9, 
   3.741442904138098*^9}, {3.741447234225637*^9, 3.741447242896728*^9}, {
   3.741449886037738*^9, 3.7414499128505507`*^9}, 3.741449947224042*^9, {
   3.741450155088587*^9, 3.741450207357006*^9}, {3.741450718637865*^9, 
   3.741450745967186*^9}, 3.74145227417661*^9, 3.741534625056912*^9, {
   3.74153466002831*^9, 3.741534680425902*^9}, 3.741535146627439*^9, 
   3.7415353982253523`*^9, 3.74153544295568*^9, 3.741539979819255*^9, 
   3.741540108020445*^9, {3.741540192963395*^9, 3.7415401968664923`*^9}, 
   3.7415838589548283`*^9, {3.741583892557959*^9, 3.741583916608584*^9}, 
   3.741583952919012*^9, 3.741584010728907*^9, 3.741707256843349*^9, 
   3.741711456334631*^9, {3.741711803738618*^9, 3.741711807517337*^9}, 
   3.741711858247666*^9, 3.741711897656233*^9, {3.74178591823311*^9, 
   3.7417859226367483`*^9}, 3.741871591779469*^9, {3.741871719184846*^9, 
   3.741871736751213*^9}, 3.7418720182177896`*^9, 3.741872378811227*^9, 
   3.74187241998291*^9, 3.741872739071734*^9, 3.7418738153814363`*^9, 
   3.7418742407586203`*^9, 3.742037966838449*^9, 3.7879992765263863`*^9},
 CellLabel->
  "Out[383]=",ExpressionUUID->"0e8d9e3f-f485-466f-ab30-e36bca6ed11e"]
}, Open  ]],

Cell["\<\
Normeringen funkar. Medelfarten \[ADoubleDot]r n\[ARing]gon miljon m/s. 

Nu kan vi \[ADoubleDot]ntligen \[OpenCurlyDoubleQuote]konvolvera\
\[CloseCurlyDoubleQuote], dvs. r\[ADoubleDot]kna ut < \[Sigma]  v >:\
\>", "Text",
 CellChangeTimes->{{3.7414299393657093`*^9, 3.74142995825471*^9}, {
   3.7414300367169113`*^9, 3.741430049129839*^9}, {3.741442925295452*^9, 
   3.7414429294116898`*^9}, {3.7414507589756527`*^9, 3.7414507631166353`*^9}, 
   3.741846695801962*^9},ExpressionUUID->"3afdd712-9ca2-46ad-8632-\
2f97e0e8932e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"prod", " ", "=", " ", 
   RowBox[{
    RowBox[{"fMaxwellval", "  ", "\[Sigma]val", " ", "vE"}], "/.", " ", 
    "vals"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "munfl"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"prod", ",", 
   RowBox[{"{", 
    RowBox[{"Ed", ",", "0", ",", "30"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "30"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "800"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"5", ",", "10", ",", "20", ",", "50", ",", "100"}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.741418995173682*^9, 3.7414190253147507`*^9}, {
   3.741423347268549*^9, 3.7414233503950577`*^9}, {3.741424031815317*^9, 
   3.7414240322015533`*^9}, {3.7414262840426292`*^9, 3.741426322597148*^9}, {
   3.741426359622526*^9, 3.7414263998655977`*^9}, {3.741429561328721*^9, 
   3.74142962078448*^9}, {3.741430134493018*^9, 3.741430135503463*^9}, {
   3.741430439147064*^9, 3.741430449239543*^9}, {3.741430549404373*^9, 
   3.7414305990678596`*^9}, {3.741440505220603*^9, 3.741440548401739*^9}, {
   3.741440661662778*^9, 3.741440663633913*^9}, {3.7414424215974827`*^9, 
   3.7414424226961603`*^9}, {3.741448270394547*^9, 3.7414483032361097`*^9}, 
   3.74145026393526*^9, {3.741540223655253*^9, 3.741540248715394*^9}, {
   3.741785935523922*^9, 3.7417860350657167`*^9}, {3.74187171324965*^9, 
   3.7418717140014668`*^9}, {3.741872402586986*^9, 3.741872404734641*^9}, {
   3.7418727210413322`*^9, 3.7418727224067*^9}, {3.741873946517568*^9, 
   3.741873979308599*^9}, {3.7418740642294397`*^9, 3.741874066584312*^9}},
 CellLabel->
  "In[384]:=",ExpressionUUID->"424683d1-862e-4222-845f-c8dc6491a937"],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwtl3c8lf/7x+2VvbPPMcpIkexz3leEUFbWOVF2yogSJWWXrMyMRCpUUvbH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        "]]},
      Annotation[#, "Charting`Private`Tag$108540#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwt13c41e//B3Aze49EGsYxzjl25jnnfpEVMhKhjKxPJWScgwhJCIlUZCWp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        "]]},
      Annotation[#, "Charting`Private`Tag$108540#2"]& ], 
     TagBox[
      {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwt13c8Vf//AHDZOzsjslJG5h3Eve+XkaxKiogkIWWPkJQR7rVCkZlQoRSh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        "]]},
      Annotation[#, "Charting`Private`Tag$108540#3"]& ], 
     TagBox[
      {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwtmPc/1g/Yt+1N1oWsyCh7ZpTrc55GKlGUEZFR2ka+RknIKCFkFCqFEknD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        "]]},
      Annotation[#, "Charting`Private`Tag$108540#4"]& ], 
     TagBox[
      {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwtl3c014/3x+0VsslKJQnZGfF+3WtmZEZFCCGSvUoy3hFFImQrPqQSlYQk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        "]]},
      Annotation[#, "Charting`Private`Tag$108540#5"]& ]}, {{}, {}}, {{{
       GraphicsGroupBox[{
         {GrayLevel[1], AbsoluteThickness[4], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
          "Round"], 
          BSplineCurveBox[{
           Offset[{0, 0}, {30, 0.6899073937657004}], 
            Offset[{0, 0}, {30, 0.6899073937657004}], 
            Offset[{0., 0.}, {30.3, 0.6899073937657004}], 
            Offset[{0., 0.}, {30.3, 0.6899073937657004}], 
            Offset[{0., 0.}, {30.6, 0.6899073937657004}], 
            Offset[{0, 0}, {32.10438903671759, 36.67543707833095}], 
            Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
             36.67543707833095}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             36.67543707833095}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             36.67543707833095}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], 
          BSplineCurveBox[{
           Offset[{0, 0}, {30, 0.6899073937657004}], 
            Offset[{0, 0}, {30, 0.6899073937657004}], 
            Offset[{0., 0.}, {30.3, 0.6899073937657004}], 
            Offset[{0., 0.}, {30.3, 0.6899073937657004}], 
            Offset[{0., 0.}, {30.6, 0.6899073937657004}], 
            Offset[{0, 0}, {32.10438903671759, 36.67543707833095}], 
            Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
             36.67543707833095}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             36.67543707833095}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             36.67543707833095}]}]}, 
         {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]]}], 
          PolygonBox[{
           Offset[{22., 7.000000000000005}, {32.10438903671759, 
             36.67543707833095}], 
            Offset[{22., -6.999999999999995}, {32.10438903671759, 
             36.67543707833095}], 
            Offset[{10.000000000000002`, -6.999999999999998}, {
             32.10438903671759, 36.67543707833095}], 
            Offset[{9.999999999999998, 7.000000000000002}, {32.10438903671759,
              36.67543707833095}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
          RotationBox["5",
           BoxRotation->0.], 
          Offset[{16., 3.552713678800501*^-15}, \
{32.10438903671759, 36.67543707833095}], {0, 0}]}], GraphicsGroupBox[{
         {GrayLevel[1], AbsoluteThickness[4], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
          "Round"], 
          BSplineCurveBox[{
           Offset[{0, 0}, {30, 98.40397547189792}], 
            Offset[{0, 0}, {30, 98.40397547189792}], 
            Offset[{0., 0.}, {30.3, 98.40397547189792}], 
            Offset[{0., 0.}, {30.3, 98.40397547189792}], 
            Offset[{0., 0.}, {30.6, 98.40397547189792}], 
            Offset[{0, 0}, {32.10438903671759, 110.02631134481591`}], 
            Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
             110.02631134481591`}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             110.02631134481591`}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             110.02631134481591`}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], 
          BSplineCurveBox[{
           Offset[{0, 0}, {30, 98.40397547189792}], 
            Offset[{0, 0}, {30, 98.40397547189792}], 
            Offset[{0., 0.}, {30.3, 98.40397547189792}], 
            Offset[{0., 0.}, {30.3, 98.40397547189792}], 
            Offset[{0., 0.}, {30.6, 98.40397547189792}], 
            Offset[{0, 0}, {32.10438903671759, 110.02631134481591`}], 
            Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
             110.02631134481591`}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             110.02631134481591`}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             110.02631134481591`}]}]}, 
         {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]]}], 
          PolygonBox[{
           Offset[{28., 7.000000000000006}, {32.10438903671759, 
             110.02631134481591`}], 
            Offset[{28., -6.999999999999994}, {32.10438903671759, 
             110.02631134481591`}], 
            Offset[{10.000000000000002`, -6.999999999999997}, {
             32.10438903671759, 110.02631134481591`}], 
            Offset[{9.999999999999998, 7.000000000000003}, {32.10438903671759,
              110.02631134481591`}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
          RotationBox["10",
           BoxRotation->0.], 
          Offset[{19., 4.218847493575595*^-15}, \
{32.10438903671759, 110.02631134481591}], {0, 0}]}], GraphicsGroupBox[{
         {GrayLevel[1], AbsoluteThickness[4], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
          "Round"], 
          BSplineCurveBox[{
           Offset[{0, 0}, {30, 698.7970608917925}], 
            Offset[{0, 0}, {30, 698.7970608917925}], 
            Offset[{0., 0.}, {30.3, 698.7970608917925}], 
            Offset[{0., 0.}, {30.3, 698.7970608917925}], 
            Offset[{0., 0.}, {30.6, 698.7970608917925}], 
            Offset[{0, 0}, {32.10438903671759, 689.9736963136868}], 
            Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
             689.9736963136868}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             689.9736963136868}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             689.9736963136868}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], 
          BSplineCurveBox[{
           Offset[{0, 0}, {30, 698.7970608917925}], 
            Offset[{0, 0}, {30, 698.7970608917925}], 
            Offset[{0., 0.}, {30.3, 698.7970608917925}], 
            Offset[{0., 0.}, {30.3, 698.7970608917925}], 
            Offset[{0., 0.}, {30.6, 698.7970608917925}], 
            Offset[{0, 0}, {32.10438903671759, 689.9736963136868}], 
            Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
             689.9736963136868}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             689.9736963136868}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             689.9736963136868}]}]}, 
         {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]]}], 
          PolygonBox[{
           Offset[{28., 7.000000000000006}, {32.10438903671759, 
             689.9736963136868}], 
            Offset[{28., -6.999999999999994}, {32.10438903671759, 
             689.9736963136868}], 
            Offset[{10.000000000000002`, -6.999999999999997}, {
             32.10438903671759, 689.9736963136868}], 
            Offset[{9.999999999999998, 7.000000000000003}, {32.10438903671759,
              689.9736963136868}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
          RotationBox["20",
           BoxRotation->0.], 
          Offset[{19., 4.218847493575595*^-15}, \
{32.10438903671759, 689.9736963136868}], {0, 0}]}], GraphicsGroupBox[{
         {GrayLevel[1], AbsoluteThickness[4], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
          "Round"], 
          BSplineCurveBox[{
           Offset[{0, 0}, {30, 688.9739450416074}], 
            Offset[{0, 0}, {30, 688.9739450416074}], 
            Offset[{0., 0.}, {30.3, 688.9739450416074}], 
            Offset[{0., 0.}, {30.3, 688.9739450416074}], 
            Offset[{0., 0.}, {30.6, 688.9739450416074}], 
            Offset[{0, 0}, {32.10438903671759, 616.6228221041999}], 
            Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
             616.6228221041999}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             616.6228221041999}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             616.6228221041999}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], 
          BSplineCurveBox[{
           Offset[{0, 0}, {30, 688.9739450416074}], 
            Offset[{0, 0}, {30, 688.9739450416074}], 
            Offset[{0., 0.}, {30.3, 688.9739450416074}], 
            Offset[{0., 0.}, {30.3, 688.9739450416074}], 
            Offset[{0., 0.}, {30.6, 688.9739450416074}], 
            Offset[{0, 0}, {32.10438903671759, 616.6228221041999}], 
            Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
             616.6228221041999}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             616.6228221041999}], 
            Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
             616.6228221041999}]}]}, 
         {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]]}], 
          PolygonBox[{
           Offset[{33., 7.000000000000007}, {32.10438903671759, 
             616.6228221041999}], 
            Offset[{33., -6.999999999999993}, {32.10438903671759, 
             616.6228221041999}], 
            Offset[{10.000000000000002`, -6.999999999999998}, {
             32.10438903671759, 616.6228221041999}], 
            Offset[{9.999999999999998, 7.000000000000002}, {32.10438903671759,
              616.6228221041999}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
          RotationBox["100",
           BoxRotation->0.], 
          Offset[{21.5, 4.773959005888173*^-15}, \
{32.10438903671759, 616.6228221041999}], {0, 0}]}]}, GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{0, 0}, {23.730465912701675`, 800.}], 
           Offset[{0, 0}, {23.730465912701675`, 800.}], 
           Offset[{0., 0.}, {23.730465912701675`, 800.}], 
           Offset[{0., 0.}, {23.730465912701675`, 800.}], 
           Offset[{0., 0.}, {23.730465912701675`, 800.}], 
           Offset[{0, 0}, {32.10438903671759, 763.3245629216691}], 
           Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
            763.3245629216691}], 
           Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
            763.3245629216691}], 
           Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
            763.3245629216691}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{0, 0}, {23.730465912701675`, 800.}], 
           Offset[{0, 0}, {23.730465912701675`, 800.}], 
           Offset[{0., 0.}, {23.730465912701675`, 800.}], 
           Offset[{0., 0.}, {23.730465912701675`, 800.}], 
           Offset[{0., 0.}, {23.730465912701675`, 800.}], 
           Offset[{0, 0}, {32.10438903671759, 763.3245629216691}], 
           Offset[{5., 1.1102230246251565`*^-15}, {32.10438903671759, 
            763.3245629216691}], 
           Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
            763.3245629216691}], 
           Offset[{10., 2.220446049250313*^-15}, {32.10438903671759, 
            763.3245629216691}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{28., 7.000000000000006}, {32.10438903671759, 
            763.3245629216691}], 
           Offset[{28., -6.999999999999994}, {32.10438903671759, 
            763.3245629216691}], 
           Offset[{10.000000000000002`, -6.999999999999997}, {
            32.10438903671759, 763.3245629216691}], 
           Offset[{9.999999999999998, 7.000000000000003}, {32.10438903671759, 
            763.3245629216691}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         RotationBox["50",
          BoxRotation->0.], 
         Offset[{19., 4.218847493575595*^-15}, \
{32.10438903671759, 763.3245629216691}], {0, 0}]}]}, {}}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->{{All, 62.25266844061112}, {All, All}},
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{0, 30}, {0, 800}},
   PlotRangeClipping->False,
   PlotRangePadding->{{0, 0}, {0, 0}},
   Ticks->{Automatic, Automatic}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.741423345037074*^9, 3.741424032836041*^9, 3.74142410103992*^9, {
   3.7414262816720552`*^9, 3.741426285676621*^9}, {3.74142631606859*^9, 
   3.741426322996091*^9}, {3.7414263612316732`*^9, 3.741426400276414*^9}, {
   3.7414295656219997`*^9, 3.741429621306593*^9}, 3.741429737120358*^9, 
   3.741430055318019*^9, 3.741430135893105*^9, 3.7414303791849957`*^9, {
   3.741430434790612*^9, 3.741430449630273*^9}, {3.741430550420329*^9, 
   3.741430599705056*^9}, 3.741440465679145*^9, 3.741440507330151*^9, {
   3.741440545409369*^9, 3.741440549005075*^9}, 3.7414417947464743`*^9, {
   3.7414424190390577`*^9, 3.741442423454628*^9}, {3.741442746022628*^9, 
   3.741442774564046*^9}, {3.741448295585067*^9, 3.741448304004703*^9}, {
   3.74144989920418*^9, 3.7414499169601173`*^9}, 3.741449950578822*^9, 
   3.741450233339856*^9, 3.741450326401211*^9, 3.741450722293144*^9, 
   3.741452277604409*^9, 3.741534625398684*^9, {3.741534660184717*^9, 
   3.741534680583735*^9}, 3.741535146789797*^9, 3.7415353984004593`*^9, 
   3.741535443108786*^9, 3.741539979986199*^9, 3.741540108177754*^9, {
   3.741540197031189*^9, 3.7415402493951*^9}, 3.7415838594413347`*^9, {
   3.7415838929332438`*^9, 3.741583917088191*^9}, 3.7415839534324827`*^9, 
   3.74158401115961*^9, 3.7417072605004396`*^9, 3.7417114564802103`*^9, {
   3.741785922785349*^9, 3.7417860357940073`*^9}, {3.7418717149383802`*^9, 
   3.7418717403038397`*^9}, 3.7418720184521713`*^9, {3.741872382262466*^9, 
   3.741872420483238*^9}, {3.741872723726368*^9, 3.741872740355605*^9}, 
   3.7418738204762077`*^9, 3.741873920856186*^9, {3.741873956137128*^9, 
   3.741873984372704*^9}, 3.7418742446407633`*^9, 3.742037970012787*^9, 
   3.787999277215974*^9},
 CellLabel->
  "Out[386]=",ExpressionUUID->"4afc12d7-c31f-472c-990a-b6e9cab9829e"]
}, Open  ]],

Cell["\<\
F\[ODoubleDot]r kBT = 5 keV har vi topp vid 10, kBT = 10 keV har topp vid 15, \
och kBT = 20 keV har topp vid 25, st\[ADoubleDot]mmer med Krane fig. 14.2. 
Reaktiviteterna vid de olika temperaturerna blir:\
\>", "Text",
 CellChangeTimes->{{3.7414502685944223`*^9, 3.741450329606127*^9}, {
  3.741450771496387*^9, 3.7414507817697906`*^9}, {3.741871605827265*^9, 
  3.741871634233821*^9}, {3.741871695103057*^9, 3.741871695306221*^9}, {
  3.74187279367808*^9, 3.741872833686241*^9}, {3.741873990242056*^9, 
  3.741873995099162*^9}},ExpressionUUID->"fc0ad79f-13a7-4a8f-9718-\
e212fd80d05f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Sigma]vmedel", " ", "=", " ", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{"prod", ",", 
    RowBox[{"{", 
     RowBox[{"Ed", ",", "0", ",", "Edcutoff"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"barn", " ", "=", " ", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"-", "28"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"barn", " ", "\[Sigma]vmedel"}]}], "Input",
 CellLabel->
  "In[387]:=",ExpressionUUID->"18c2061e-021d-44f8-ab82-d8141b2a32c3"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "1085.1337651400395`", ",", "6710.13041770335`", ",", 
    "26003.618013057003`", ",", "89496.71716792861`", ",", 
    "164923.72396802175`"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7414504281055193`*^9, 3.741452280483654*^9, 3.7415346254454403`*^9, {
   3.74153466022906*^9, 3.741534680628845*^9}, 3.7415351468367653`*^9, 
   3.74153539844566*^9, 3.741535443154532*^9, 3.7415399800346746`*^9, 
   3.74154010822655*^9, 3.741540197077742*^9, 3.7415838598519793`*^9, {
   3.741583893265211*^9, 3.741583917546906*^9}, 3.741583953819002*^9, 
   3.7415840115186167`*^9, 3.741707279680483*^9, 3.741711456523855*^9, 
   3.7417859228895397`*^9, {3.741871719488432*^9, 3.741871740899847*^9}, 
   3.7418720188131533`*^9, 3.74187238254244*^9, 3.741872420682674*^9, 
   3.741872740739398*^9, 3.7418742481755466`*^9, 3.742037972333744*^9, 
   3.78799927727001*^9},
 CellLabel->
  "Out[387]=",ExpressionUUID->"1903f33f-247c-4f04-82a6-de372590abe6"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "1.0851337651400396`*^-25", ",", "6.71013041770335`*^-25", ",", 
    "2.6003618013057006`*^-24", ",", "8.949671716792862`*^-24", ",", 
    "1.6492372396802175`*^-23"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.7414504281055193`*^9, 3.741452280483654*^9, 3.7415346254454403`*^9, {
   3.74153466022906*^9, 3.741534680628845*^9}, 3.7415351468367653`*^9, 
   3.74153539844566*^9, 3.741535443154532*^9, 3.7415399800346746`*^9, 
   3.74154010822655*^9, 3.741540197077742*^9, 3.7415838598519793`*^9, {
   3.741583893265211*^9, 3.741583917546906*^9}, 3.741583953819002*^9, 
   3.7415840115186167`*^9, 3.741707279680483*^9, 3.741711456523855*^9, 
   3.7417859228895397`*^9, {3.741871719488432*^9, 3.741871740899847*^9}, 
   3.7418720188131533`*^9, 3.74187238254244*^9, 3.741872420682674*^9, 
   3.741872740739398*^9, 3.7418742481755466`*^9, 3.742037972333744*^9, 
   3.787999277280772*^9},
 CellLabel->
  "Out[389]=",ExpressionUUID->"0c85bd81-43ba-495c-aa95-a2746bac0f04"]
}, Open  ]],

Cell["\<\
Stoppade in 1 barn = 10^(-28) m^2, 
gav reaktivitet i enheten  m^2 (m/s) = m^3/s . 
Det sista v\[ADoubleDot]rdet skall vara 5 x 10^(-23) f\[ODoubleDot]r 100 keV \
(Krane s.542), s\[ARing] vi har tydligen r\[ADoubleDot]tt storleksordning, \
men fattas en faktor 3 ungef\[ADoubleDot]r, det r\[ADoubleDot]cker f\
\[ODoubleDot]r oss nu. 

Kontentan \[ADoubleDot]r att deuterium-deuterium-fusion h\[ADoubleDot]nder \
\[OpenCurlyDoubleQuote]ganska ofta\[CloseCurlyDoubleQuote]. Hade vi t.ex. \
haft 150 g\[ARing]nger vattens densitet, som i solen, har vi 81 miljoner \
fusioner per sekund vid temperatur 100 keV:\
\>", "Text",
 CellChangeTimes->{{3.741448519956132*^9, 3.7414485245841627`*^9}, {
  3.7414486131465816`*^9, 3.741448629916923*^9}, {3.7414497869203176`*^9, 
  3.741449812997058*^9}, {3.741450259292927*^9, 3.7414502726530333`*^9}, {
  3.741450630850567*^9, 3.7414507047181463`*^9}, {3.741450844452317*^9, 
  3.741450847429881*^9}, {3.74187283710852*^9, 3.7418729902750053`*^9}, {
  3.741874005781707*^9, 3.741874006587352*^9}, {3.741874075684841*^9, 
  3.741874108419354*^9}, {3.741874258649171*^9, 3.7418742595619087`*^9}, {
  3.788331869931872*^9, 
  3.788331894649023*^9}},ExpressionUUID->"25724319-cb84-4c5f-91b0-\
004ef1ab9131"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"waternumberdensity", " ", "=", " ", 
   RowBox[{"33", "  ", 
    RowBox[{"10", "^", "27"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"150", " ", "waternumberdensity", " ", "barn", " ", 
  "\[Sigma]vmedel"}]}], "Input",
 CellChangeTimes->{{3.741448535064135*^9, 3.741448568558284*^9}},
 CellLabel->
  "In[390]:=",ExpressionUUID->"d31add2c-17bc-4c8e-a94b-32755b3631b0"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "537141.2137443195`", ",", "3.321514556763158`*^6", ",", 
    "1.2871790916463217`*^7", ",", "4.430087499812466`*^7", ",", 
    "8.163724336417076`*^7"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.741448554070176*^9, 3.741448569556636*^9}, 
   3.741449921634794*^9, 3.741449953557662*^9, 3.741452289834091*^9, 
   3.7415346255076103`*^9, {3.741534660293687*^9, 3.741534680695898*^9}, 
   3.741535146908922*^9, 3.741535398517393*^9, 3.741535443221463*^9, 
   3.741539980104869*^9, 3.7415401082988243`*^9, 3.741540197143325*^9, 
   3.7415838603377237`*^9, {3.7415838940265827`*^9, 3.7415839178975697`*^9}, 
   3.741583954311541*^9, 3.741584012002244*^9, 3.7417072903815937`*^9, 
   3.741711456574028*^9, 3.7417859229664392`*^9, {3.741871719804854*^9, 
   3.74187174126276*^9}, 3.741872382609433*^9, 3.741872423843237*^9, 
   3.741872740839015*^9, 3.741874262077075*^9, 3.742037975204623*^9, 
   3.7879992773392067`*^9},
 CellLabel->
  "Out[391]=",ExpressionUUID->"c9d2bfbc-3782-4ee1-b100-8021746385ff"]
}, Open  ]],

Cell["\<\
Men 150 g\[ARing]nger vattens densitet \[ADoubleDot]r mer \[ADoubleDot]n f\
\[ODoubleDot]r fasta \[ADoubleDot]mnen p\[ARing] jorden, och det h\
\[ADoubleDot]r \[ADoubleDot]r en (laddad) gas! S\[ARing] i en fusionsreaktor \
\[ADoubleDot]r realistiska densiteter mycket l\[ADoubleDot]gre, kanske 10^21 \
partiklar/m^3. Multiplicerar vi det med frigjord energi per partikel blir det \
effekt-densitet:
 (antal/m^3)^2 x m^3/s     J    =   J/(s m^3) =  watt / m^3. 
F\[ODoubleDot]r 10^21 partiklar/m^3 blir det 5 MW per kubikmeter:\
\>", "Text",
 CellChangeTimes->{{3.741441892287402*^9, 3.741442087123794*^9}, {
   3.741442498951346*^9, 3.741442540377667*^9}, {3.7414428127030973`*^9, 
   3.741442832818919*^9}, {3.741442938922374*^9, 3.741442966970323*^9}, {
   3.741447297857863*^9, 3.7414473029150047`*^9}, {3.741448352605751*^9, 
   3.74144839700229*^9}, {3.741448450032508*^9, 3.741448476771706*^9}, 
   3.7414485164919167`*^9, {3.741448662721157*^9, 3.741448704547758*^9}, {
   3.741872996213727*^9, 3.7418730606620493`*^9}, {3.7418731610097923`*^9, 
   3.741873222129546*^9}, {3.741873304844499*^9, 3.7418733120055227`*^9}, {
   3.7418733627058067`*^9, 3.741873376484342*^9}, {3.741873469321114*^9, 
   3.741873483328557*^9}, {3.7883319082597017`*^9, 
   3.788331916565727*^9}},ExpressionUUID->"c5b50b98-ccfc-45b2-ab6e-\
731da259f4f9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"njon", " ", "=", " ", 
   RowBox[{"10", "^", "21"}]}], ";", " ", 
  RowBox[{"Q", "   ", "=", "  ", 
   RowBox[{"4000", " ", "keV"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"effektfaktor", " ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"njon", "^", "2"}], " ", "/", "2"}], ")"}], "  ", "barn", " ", 
   RowBox[{"\[Sigma]vmedel", "[", 
    RowBox[{"[", "5", "]"}], "]"}], "  ", "Q"}]}]}], "Input",
 CellChangeTimes->{{3.7414420996710176`*^9, 3.741442115566101*^9}, {
   3.7414423069489393`*^9, 3.741442307909133*^9}, {3.7414424380392313`*^9, 
   3.741442456637884*^9}, {3.741442548132923*^9, 3.74144255117568*^9}, {
   3.7414426098457623`*^9, 3.741442616635021*^9}, {3.741442653741156*^9, 
   3.7414426559943943`*^9}, {3.7414469762965097`*^9, 3.741446979911667*^9}, {
   3.74144703604242*^9, 3.741447043556881*^9}, {3.741447359377631*^9, 
   3.741447432039768*^9}, {3.7414476711313868`*^9, 3.741447671325416*^9}, {
   3.741448283073073*^9, 3.7414482835579977`*^9}, {3.741448646940963*^9, 
   3.74144866887107*^9}, {3.741450884393766*^9, 3.741450884507107*^9}, 
   3.741451164096898*^9, {3.7414512020694237`*^9, 3.7414512022574453`*^9}, {
   3.741535376488842*^9, 3.7415353836096*^9}, {3.741712263815288*^9, 
   3.741712263970796*^9}, {3.741873407600822*^9, 3.7418734581990147`*^9}, {
   3.741874383047798*^9, 3.7418743939088907`*^9}},
 CellLabel->
  "In[392]:=",ExpressionUUID->"3d620c3e-f5ff-4f5d-aa88-ffdde57aacec"],

Cell[BoxData[
 FormBox["5.284156115935416`*^6", TraditionalForm]], "Output",
 CellChangeTimes->{{3.741442443123694*^9, 3.741442457296853*^9}, 
   3.741442551822894*^9, 3.741442617396072*^9, 3.741442656749763*^9, {
   3.74144276005866*^9, 3.741442780829002*^9}, 3.741446982729595*^9, 
   3.741447044338977*^9, {3.7414473841350946`*^9, 3.7414474327980337`*^9}, 
   3.7414498275441103`*^9, 3.741449924719676*^9, 3.741450885280751*^9, 
   3.741451166708828*^9, 3.741451203261688*^9, 3.741451284602154*^9, 
   3.741452292868029*^9, 3.7415346255741367`*^9, {3.741534660360202*^9, 
   3.741534680763165*^9}, 3.741535146975684*^9, {3.741535381303741*^9, 
   3.741535398601872*^9}, 3.741535443289209*^9, 3.741539980205145*^9, 
   3.741540108364257*^9, 3.741540197210074*^9, 3.7415838604350443`*^9, {
   3.7415838941042843`*^9, 3.7415839179707727`*^9}, 3.741583954387694*^9, 
   3.741584012075725*^9, 3.741707294302021*^9, 3.7417114566728897`*^9, 
   3.74171226557226*^9, 3.741785923033245*^9, {3.741871719867949*^9, 
   3.741871741333692*^9}, 3.7418723826422977`*^9, 3.741872424013742*^9, 
   3.741872740921996*^9, {3.7418734085443373`*^9, 3.741873419545535*^9}, {
   3.741873451288946*^9, 3.741873458732737*^9}, 3.7418742652439833`*^9, {
   3.741874391957232*^9, 3.7418743944569807`*^9}, 3.742037977730465*^9, 
   3.787999277539586*^9},
 CellLabel->
  "Out[393]=",ExpressionUUID->"be50cdc6-4a40-411a-b2b3-8b57152e3a5e"]
}, Open  ]],

Cell["\<\
(Faktorn 2 \[ADoubleDot]r f\[ODoubleDot]r att man inte skall dubbelr\
\[ADoubleDot]kna reaktioner.)
I solen \[ADoubleDot]r det l\[ARing]g effekt-densitet, som en komposth\
\[ODoubleDot]g! Men det \[ADoubleDot]r OK f\[ODoubleDot]r solen har s\[ARing] \
m\[ARing]nga protoner totalt och s\[ARing] mycket plats totalt. P\[ARing] \
jorden m\[ARing]ste vi packa ihop det lite mer. 

Men inte ens med 5 MW/m^3 fr\[ARing]n fusion vet vi att det blir n\[ARing]got \
kraftverk: vi m\[ARing]ste ta med i ber\[ADoubleDot]kningen att det kostar \
energi att h\[ARing]lla ig\[ARing]ng reaktionen. \[CapitalARing]r 1955 gav \
John Lawson en uppskattning av det (nuf\[ODoubleDot]rtiden finns det mer \
sofistikerade argument, men vi tar det h\[ADoubleDot]r som grundid\[EAcute]). \
J\[ADoubleDot]mf\[ODoubleDot]r f\[ODoubleDot]rst med str\[ARing]lningsf\
\[ODoubleDot]rluster, och kolla hur h\[ODoubleDot]g temperaturen m\[ARing]ste \
vara f\[ODoubleDot]r att fusion skall ge mer energi:\
\>", "Text",
 CellChangeTimes->{{3.7414185717368298`*^9, 3.741418608353159*^9}, {
  3.741448171871687*^9, 3.7414482060624647`*^9}, {3.741449839913027*^9, 
  3.7414498622866*^9}, {3.741712340661562*^9, 3.74171236396144*^9}, {
  3.741873494495429*^9, 3.741873516759226*^9}, {3.74187356592059*^9, 
  3.7418737005521727`*^9}, {3.741874139429716*^9, 3.741874175666031*^9}, {
  3.788331940565043*^9, 
  3.7883319675256*^9}},ExpressionUUID->"09bb1e00-a86f-4663-92b7-a62328e26241"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Pconst", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"kC", "^", "3"}], " ", 
    RowBox[{"(", 
     RowBox[{"4", 
      RowBox[{"\[Pi]", "/", "3"}]}], ")"}], 
    RowBox[{"e", "^", "6"}], 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"3", "/", "me"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"me", " ", 
       RowBox[{"c", "^", "3"}], " ", "hbar"}], ")"}]}], " ", 
    RowBox[{"Sqrt", "[", "keV", "]"}]}], "/.", " ", 
   "vals"}]}], "\[IndentingNewLine]", 
 RowBox[{"Prad", " ", "=", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"Pconst", " ", 
     RowBox[{"Za", "^", "2"}], " ", 
     RowBox[{
      RowBox[{"njon", "^", "2"}], "/", "2"}], " ", 
     RowBox[{
      RowBox[{"(", "kBTkeV", ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}]}]}], " ", "/.", " ", "vals"}], " ", "/.",
    " ", 
   RowBox[{"kBT", "\[Rule]", 
    RowBox[{"kBTkeV", " ", "keV"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.7414177414421177`*^9, 3.7414177415735703`*^9}, {
  3.741418284743*^9, 3.741418291688642*^9}, {3.741442335939866*^9, 
  3.741442351449635*^9}, {3.7414474410452433`*^9, 3.741447475234199*^9}, {
  3.741447560340682*^9, 3.741447568017933*^9}, {3.7414476766904287`*^9, 
  3.741447678076*^9}, {3.741447742148675*^9, 3.7414478187795267`*^9}, {
  3.741447892337097*^9, 3.741447968374497*^9}, {3.7414480102575502`*^9, 
  3.74144801707585*^9}, {3.741449069897719*^9, 3.7414490990252542`*^9}, {
  3.741449189659223*^9, 3.741449212409463*^9}, {3.741451024992674*^9, 
  3.741451124447092*^9}, {3.741712176141533*^9, 3.741712179244923*^9}, {
  3.741873710828277*^9, 3.741873727512307*^9}, {3.741874190092478*^9, 
  3.741874193392529*^9}},
 CellLabel->
  "In[394]:=",ExpressionUUID->"aded8900-dcf9-40a3-978e-40f2780d01b1"],

Cell[BoxData[
 FormBox["4.582679516561741`*^-37", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.741440466152025*^9, {3.741447452775159*^9, 3.741447476034679*^9}, 
   3.741447569000956*^9, 3.7414476786053867`*^9, {3.74144781254335*^9, 
   3.741447819244379*^9}, {3.741447853180848*^9, 3.7414478704824867`*^9}, {
   3.741447933554729*^9, 3.741447968741747*^9}, {3.741448011754657*^9, 
   3.741448017524506*^9}, 3.7414487776050873`*^9, {3.741449072668214*^9, 
   3.741449080351736*^9}, 3.7414491249705544`*^9, {3.741449193165443*^9, 
   3.741449213034243*^9}, {3.741449927721101*^9, 3.741449956690494*^9}, {
   3.741451060981696*^9, 3.7414511251385717`*^9}, 3.741451287837851*^9, 
   3.7414522958021517`*^9, 3.74153462564085*^9, {3.741534660427273*^9, 
   3.741534680829687*^9}, 3.741535147041273*^9, 3.741535398684382*^9, 
   3.74153544335576*^9, 3.741539980271718*^9, 3.741540108432253*^9, 
   3.741540197443819*^9, 3.7415838605188847`*^9, {3.741583894202491*^9, 
   3.7415839180547867`*^9}, 3.741583954454205*^9, 3.741584012159367*^9, 
   3.741707297148828*^9, 3.7417114567390614`*^9, 3.7417121796981907`*^9, 
   3.741712268756587*^9, 3.7417859230986147`*^9, {3.741871719934306*^9, 
   3.741871741432987*^9}, 3.741872382711193*^9, 3.74187242408108*^9, 
   3.741872740971818*^9, {3.741873712774145*^9, 3.741873728176111*^9}, 
   3.741874194171302*^9, 3.741874267924285*^9, 3.742037980919488*^9, 
   3.787999277613901*^9},
 CellLabel->
  "Out[394]=",ExpressionUUID->"4ca6bef6-b11e-459d-b045-9463ce841727"],

Cell[BoxData[
 FormBox[
  RowBox[{"229133.97582808704`", " ", 
   SqrtBox["kBTkeV"]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.741440466152025*^9, {3.741447452775159*^9, 3.741447476034679*^9}, 
   3.741447569000956*^9, 3.7414476786053867`*^9, {3.74144781254335*^9, 
   3.741447819244379*^9}, {3.741447853180848*^9, 3.7414478704824867`*^9}, {
   3.741447933554729*^9, 3.741447968741747*^9}, {3.741448011754657*^9, 
   3.741448017524506*^9}, 3.7414487776050873`*^9, {3.741449072668214*^9, 
   3.741449080351736*^9}, 3.7414491249705544`*^9, {3.741449193165443*^9, 
   3.741449213034243*^9}, {3.741449927721101*^9, 3.741449956690494*^9}, {
   3.741451060981696*^9, 3.7414511251385717`*^9}, 3.741451287837851*^9, 
   3.7414522958021517`*^9, 3.74153462564085*^9, {3.741534660427273*^9, 
   3.741534680829687*^9}, 3.741535147041273*^9, 3.741535398684382*^9, 
   3.74153544335576*^9, 3.741539980271718*^9, 3.741540108432253*^9, 
   3.741540197443819*^9, 3.7415838605188847`*^9, {3.741583894202491*^9, 
   3.7415839180547867`*^9}, 3.741583954454205*^9, 3.741584012159367*^9, 
   3.741707297148828*^9, 3.7417114567390614`*^9, 3.7417121796981907`*^9, 
   3.741712268756587*^9, 3.7417859230986147`*^9, {3.741871719934306*^9, 
   3.741871741432987*^9}, 3.741872382711193*^9, 3.74187242408108*^9, 
   3.741872740971818*^9, {3.741873712774145*^9, 3.741873728176111*^9}, 
   3.741874194171302*^9, 3.741874267924285*^9, 3.742037980919488*^9, 
   3.787999277634027*^9},
 CellLabel->
  "Out[395]=",ExpressionUUID->"7fa691a3-1603-4b97-9035-c386d7b95caf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Prad", ",", 
     RowBox[{"NIntegrate", "[", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"njon", "^", "2"}], " ", "/", "2"}], ")"}], "  ", "barn", 
          "  ", "Q", "  ", "2", " ", "keV", " ", "fMaxwell", " ", 
          "\[Sigma]val", " ", "vE"}], "/.", "\[VeryThinSpace]", 
         RowBox[{"kBT", "\[Rule]", 
          RowBox[{"kBTkeV", " ", "keV"}]}]}], "/.", "\[VeryThinSpace]", 
        "vals"}], ",", 
       RowBox[{"{", 
        RowBox[{"Ed", ",", "0", ",", "Edcutoff"}], "}"}]}], "]"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"kBTkeV", ",", "1", ",", "200"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.741447500106887*^9, 3.741447506129725*^9}, {
   3.741448034079619*^9, 3.741448039058169*^9}, {3.74144878294558*^9, 
   3.741448802918744*^9}, {3.741449011846548*^9, 3.741449023867939*^9}, 
   3.741449239805757*^9, {3.741449278256444*^9, 3.741449278418037*^9}, {
   3.7414493546749277`*^9, 3.741449408050913*^9}, {3.741449930796981*^9, 
   3.7414499426828623`*^9}, {3.741451297347171*^9, 3.741451297684288*^9}, {
   3.741452304045032*^9, 3.741452304541603*^9}, {3.74145242833987*^9, 
   3.7414524285004*^9}, {3.74154016071132*^9, 3.741540173365511*^9}, {
   3.741707305256686*^9, 3.7417073114331913`*^9}, {3.741712011183359*^9, 
   3.741712011309235*^9}, 3.741712188023425*^9, {3.741712305132285*^9, 
   3.741712317272822*^9}, {3.74187435226834*^9, 3.741874359477133*^9}, {
   3.7418743983615627`*^9, 3.741874399738618*^9}},
 CellLabel->
  "In[396]:=",ExpressionUUID->"3c2de956-0735-4f56-a822-2875d5ecf32a"],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Xs0lAkYBnC55NqY+L5VnKGm28w381GUS+J7UruVTTsNqeSoxBQtos1i
U0hRVG61WjmDRqJ1y5KVShek1tkOe1rpqCOGhHKNUZP99o/3vOf3x3Oec953
sX+YNFBTQ0PDg53/d7+5wDptbqzrjgi3Zn65ACOvdvbz8nyYyusD355nnXfS
obNHHsxwXqU9nmIdtb2ovUkewzRvePPgrwoBAtbuldTKzzFO5PH6yFsCdFrf
4VTKf2Msa6srn1YLQAoHQkrlJUy/WnA1ol4A2+VxuTfldUzUWePwhy0CSMtP
VUjuPWMque0yeZ8A/mYuI59z/mEq1LbVGXOEuKpo+6Syf8UoPT1Kv1oIkWaR
EFu4spuxMfcbLXIUIi93hemV5F6G+c7wwkFPIXbwc1bYC94xgW/LIgOOCPG0
dc/RdzWDTEO/kX5nqhDzbIvbAvU+Mm+luhOBRULEbPXf1SQZZcytpymbx2ze
1377/a9jjFnY6TrOGyHSZyuUbooJ5vuFreMylRBWigynnJBPTJadYfQXkgJR
uNZs94Jp5lqV0vvGSgp7irb8MdinYp5cq4lL96Cg5TI7pFf6meGr13uNB1Ew
sfmlPMVLzWyoD4o7nEghgu+3qsdqlokeTJpelE+B9+cpS4lMA5Fxbi1DdyiU
dBtqX9k2B0mnx5WTHRT6PQ86FNlq4u9xv99/nqSwa6LQ5pCuFrqaZc+MuSJE
kNlJph+0oGEUaK8Ui3A/IEQR3qiN99WzquebRKhXk8aXsnVg0OJ1cI2/iL13
xMuC2Llw3Zq36N8TIqzbW3nogKcu1q5Jtr14hc2vUOzkOOvB/YIsLbFGhDGn
4KwTlvpIk8z+OtYmwu4Y08v5Y/rIjVo9HTksQpDzkamyDgPc5+5TOBqIUUpV
8MLKDXGDIyjmLhMj/8Cj9Il4IzQdK9m5nxHDlXcuMEA2DzNbl0g/7hGDo7P6
6xlnDibOOhZmRoqRHJL+KZNvDC2HjRuPZYqxRrutynPGGC+3DDmHlInhPhax
d0jGhbJxW1fXEzFaC14Qipdc6NwqepqiFCP4/U1x9cb5GNbK5Uo0aPiO+fx0
p3Y+BhqTC7bzaCyXj/srKBNYjFq/fuZEQ79HXdWXZQIiITzC14vG+v7u1ZZ6
puCfKpFS4TQyExwWlB81xdTAyRROKo27DyML+F2mmFNnHHr4Og3nRxd9U34g
sHjm0lWdRzTafcyjPeoI6ObVLqnporHZJUlE1RNQdHhK6Nc07llNdM29R2D9
/I/HFaxLelvdGh4QiE1Y9iLjDY2E0HgjuxYC4wEZyWHdNFYmvJMv6CDwWvjj
sEBJ43xxTVPPJIHqKqvbOUM0NFOXRDdMEZAO1fWYDNOICk0T5aoIjCz15p5j
HWAXnOatJiC6nBoU9YHGurs8nxZtEvlRKosdIzTeP08cLjMlkerSHseZoLGv
alSeQpKgIkNLT7N+cclPesiMRHOZfucX1g98HG8vtiChuQh2g5M0snsH47L4
JKI0S5XNUzQ4zbvswpeS+MZ5swkzTSOxuFHpsZxE1dEe1xrWR0Ll7roUiQ+9
C7MVKhp9EiN1j4jt51U/tphh/2UXXd5AkxB6S0YzWLeRfftzbUg0XRjkGXym
sWlaSsSsIhHQfMY9nvV/EXQiZQ==
        "]]},
      Annotation[#, "Charting`Private`Tag$109131#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Hk41HkABnC5z3HM75diJ5lax2C+RZTQ711la9uK2HKkyJVsiGwrHuVo
S6wHUUvyjOxItDnSoZy50qF66LFR2lrXLKlM02CFnf3jfd7n88/7x2scEOke
LC8nJ7ddlv971MCMn6WcsKHjVX+xNE4LH196jnKKfJhEv4/pFRlaKDqxtn9Q
EMZophZkBhZpIXZnaU+HII6JqdwhamvXQtB6P7daQRrzID50LEiHhX5+Hata
cIEZS3FMNyhhgTb/J/yaoJxx0tHT8HusDWuTxMKrgrtMxpRr/mo1XbhXplS5
NT5iRPIXftYNZyNA3+njbMFzZiy+K/Z4No2Lwm7pjN1Lpo7iHY0+r48sw+SE
klVvGQfFdRm9VUtRVGjKzk8dYkKSfruhnGOIXdwCUzszETPW4zi1OZWDh117
johujTObXXK4hX5G0LIu6w5W/cD46JqrVyUvR9y2AK8Ot0lmnOocEO81xi5f
u51N82Jmv+GXHA6Xi+yFqmFnoYRZZJR66lY/F0bCs/YF4VLmySuDlKsXVoAq
Wa/vvWSaOWnNV3b8diX2lH53Y3xkhpFEpYe6TK+EgtPCO9Vrs4xoYMLcTfA1
9Eh8ZfoPc4zxZ6/fI9eYIJq7b/Wg0QKzXGrbx3tqAs6dlGVuIXK4bUeanLxN
Uf5WQzF/xyK0hZ9KJCJTjHocWFtqLY93LUrKyhFm8JKUkFAVBfBWpWhtGTZD
NJ13mv1eAXHn7Dqr/c3RFBQujGpXROJkrOf5J+aon6O1z+UpgRWS1XTClif7
O7qvOEEZH9R6x98LeHD0qw4N9FCBdOCp9Mw8D02mQk+Wgyr+rHfp5/hbQGwf
lnt8mRocdlTQVJ0FvOPY5y+J1aA5vCGsRcMSBx0OT1W8UMdGS5eZN/sscY1X
xYms1IB1NWlPumKJS4Gt2ZIkTbDWfe9sMGGJDZy04KAQLRxW2ONWbmMFltKa
+VMOLBwqktovRFkhNTxbmsPVRky49P7f1VawVeyu8fhXG5L5I0dtx6ywVRzt
9y5EB8/NRQ0Hl/HRVdxLCft08NpzcqDTg4+wsauWNzfpwupVYNLlZD58xT4x
dbW6mN/busjrOh8mgk8BQp4eDr75pG/6mg+1wbmakVw9FKoL2w8pEnwz+nbN
MlU2/HmNOdYWBDnJa5dUHmEjMi0xc2IbQUPL0WLuABuumbMzrT8SOLRm+qa7
UjjbUPD4WRpBj4/Bse13KdhezIy+WEKwxem0Ba+ews4PLZHalwkajSQDyo0U
jO7nbkqWuXyoy7n5HoW+KaufDpQSJEckado8oLDx0biYlBGsShYJlryg8Euw
U8idPwgyym51DH6mkDbu4l1RQyD/64pjzVMUDF927v7qBkFsRJZF4QyFM0q1
lmkyB9mEZe2eo/DlhGR/8E0CxwaOzwNFGt0qeeKltwnGnp2cqGDT+Gvx4uvx
dwn8ayYF6TQN6sBu+1GZe8/tcw/VpxGzKzTfvY7gns+628aGNC5tNBgyqyfI
GxpPzOXSUK8KEfY0ELDue9lEraTR4DwkdmokOFnWPrzdhMbezmCDKzIfjhBs
VeHRSGjLkMQ3EYy4ac4NWsj22lA6LLOvzbHKZisasw91bFybCbrpkf2FhMb0
UsW8Wpk3T7tTcatpsD4t7zW+R/Af/WwbkA==
        "]]},
      Annotation[#, "Charting`Private`Tag$109131#2"]& ]}, {}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 3.6850407336274627`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Exp[
        Part[#, 1]], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Exp[
        Part[#, 1]], 
       Exp[
        Part[#, 2]]}& )},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Log, Exp}]}, {
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Log, Exp}]}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None},
   PlotRange->NCache[{{0, 
       Log[200]}, {3.6850407336274627`, 15.877211276552341`}}, {{
      0, 5.298317366548036}, {3.6850407336274627`, 15.877211276552341`}}],
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->FrontEndValueCache[{
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledTicks[{Log, Exp}]}, {{{0., 
        FormBox["1", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
        FormBox["5", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {2.302585092994046, 
        FormBox["10", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {3.912023005428146, 
        FormBox["50", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {4.605170185988092, 
        FormBox["100", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.791759469228055, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.995732273553991, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.0943445622221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.248495242049359, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.382026634673881, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.499809670330265, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5.298317366548036, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5.703782474656201, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5.991464547107982, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.214608098422191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.396929655216146, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.551080335043404, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.684611727667927, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.802394763324311, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.907755278982137, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.003065458786462, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.090076835776092, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.170119543449628, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.24422751560335, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.313220387090301, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.3777589082278725`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}, {{4.605170185988092, 
        FormBox["100", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {6.907755278982137, 
        FormBox["1000", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {9.210340371976184, 
        FormBox[
         TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
          SuperscriptBox], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
          SuperscriptBox], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
          SuperscriptBox], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {16.11809565095832, 
        FormBox[
         TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
          SuperscriptBox], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {2.302585092994046, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.995732273553991, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.912023005428146, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.0943445622221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.248495242049359, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.382026634673881, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.499809670330265, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5.298317366548036, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5.703782474656201, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5.991464547107982, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.214608098422191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.396929655216146, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.551080335043404, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.684611727667927, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.802394763324311, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.600902459542082, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8.006367567650246, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8.294049640102028, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8.517193191416238, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8.699514748210191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8.85366542803745, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8.987196820661973, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {9.104979856318357, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {9.903487552536127, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {10.308952660644293`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {10.596634733096073`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {10.819778284410283`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {11.002099841204238`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {11.156250521031495`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {11.289781913656018`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {11.407564949312402`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12.206072645530174`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12.611537753638338`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12.89921982609012, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {13.122363377404328`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {13.304684934198283`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {13.458835614025542`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {13.592367006650065`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {13.710150042306449`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14.508657738524219`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14.914122846632385`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {15.201804919084164`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {15.424948470398375`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {15.60727002719233, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {15.761420707019587`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {15.89495209964411, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16.012735135300492`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16.811242831518264`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {17.216707939626428`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {17.50439001207821, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {17.72753356339242, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {17.909855120186375`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.064005800013632`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.197537192638155`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.31532022829454, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.420680743952367`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.51599092375669, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.60300230074632, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.683045008419857`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.75715298057358, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.82614585206053, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.890684373198102`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.741447496327014*^9, 3.741447507741764*^9}, 
   3.74144757227017*^9, 3.741447683001598*^9, {3.741448021091331*^9, 
   3.7414480401927423`*^9}, {3.741448779888212*^9, 3.74144880382516*^9}, {
   3.7414490151756353`*^9, 3.7414490269682007`*^9}, {3.7414492257396717`*^9, 
   3.741449243699514*^9}, 3.741449282063285*^9, {3.741449358529811*^9, 
   3.741449409002801*^9}, 3.741449869511949*^9, {3.741449932608637*^9, 
   3.741449959646132*^9}, 3.741450890266282*^9, {3.741451291178602*^9, 
   3.741451298988772*^9}, {3.741452298979289*^9, 3.741452305613727*^9}, 
   3.7414524316195374`*^9, 3.74153463093926*^9, {3.741534661558755*^9, 
   3.7415346825807858`*^9}, 3.741535149176601*^9, 3.74153540037458*^9, 
   3.741535445239523*^9, 3.741539981621875*^9, 3.741540109950446*^9, {
   3.741540162895499*^9, 3.7415401985402117`*^9}, 3.741583861811614*^9, {
   3.741583895487339*^9, 3.741583919405002*^9}, 3.741583956467939*^9, 
   3.741584013420638*^9, {3.7417073020440407`*^9, 3.741707312389441*^9}, 
   3.741711457792297*^9, 3.7417120127240067`*^9, {3.7417121832224493`*^9, 
   3.7417121897306557`*^9}, 3.741712272514324*^9, {3.741712306299917*^9, 
   3.741712318258953*^9}, 3.741785924052544*^9, {3.741871722195869*^9, 
   3.741871745021019*^9}, 3.741872383307927*^9, 3.7418724247634077`*^9, 
   3.74187274209099*^9, 3.741873742424368*^9, 3.7418741981833963`*^9, 
   3.741874271298757*^9, 3.7418743651802*^9, 3.741874400790038*^9, 
   3.7420379841484947`*^9, 3.787999278283936*^9},
 CellLabel->
  "Out[396]=",ExpressionUUID->"bc8eb2e8-5293-4dfd-b0d3-7714ade732cc"]
}, Open  ]],

Cell["\<\
Skall korsa vid 40 keV, h\[ADoubleDot]r f\[ARing]r vi ungef\[ADoubleDot]r 30 \
keV. 

Om fusionsenergi \[ADoubleDot]r st\[ODoubleDot]rre \[ADoubleDot]n den gr\
\[ADoubleDot]nsen, t.ex. 100 keV f\[ODoubleDot]r deuterium-fusion, s\[ARing] \
kan vi f\[ODoubleDot]rsumma str\[ARing]lningsf\[ODoubleDot]rlusten Prad.
Vi m\[ARing]ste \[ADoubleDot]nd\[ARing] betala f\[ODoubleDot]r att \
h\[ARing]lla temperaturen uppe, det \[ADoubleDot]r andra aspekten av \
\[CloseCurlyDoubleQuote]Lawsons kriterium\[CloseCurlyDoubleQuote]. Termiska \
energin  \[ADoubleDot]r 3 n kB T (som vi diskuterar p\[ARing] kurs i \
termodynamik: 3/2 f\[ODoubleDot]r en partikel i 3D och vi har joner + \
elektroner)
S\[ARing] f\[ODoubleDot]r densitet 10^21 partiklar/m^3 f\[ARing]r vi den \
mycket viktiga tiden \[Tau] : hur l\[ADoubleDot]nge fusionen m\[ARing]ste h\
\[ARing]llas ig\[ARing]ng f\[ODoubleDot]r att f\[ARing] ut nettoenergi av \
fusion. H\[ADoubleDot]r \[ADoubleDot]r exempel vid temperatur 100 keV:\
\>", "Text",
 CellChangeTimes->{{3.741418295492968*^9, 3.741418324446456*^9}, {
  3.741418358422954*^9, 3.741418363999789*^9}, {3.741448213905036*^9, 
  3.741448217072542*^9}, {3.7414523432077417`*^9, 3.741452353542179*^9}, {
  3.741452435605987*^9, 3.74145244530058*^9}, {3.741786062323987*^9, 
  3.741786090499878*^9}, {3.741788515357161*^9, 3.741788743189383*^9}, {
  3.741788776924961*^9, 3.741788786003015*^9}, {3.74178902494396*^9, 
  3.741789061897417*^9}, {3.741874405821471*^9, 3.7418744603222446`*^9}, {
  3.78833197581349*^9, 
  3.788331976480689*^9}},ExpressionUUID->"10a88a98-b22d-4e49-8200-\
852b50d9251f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", " ", "njon", " ", "100", " ", "keV"}], " ", ",", 
     RowBox[{"NIntegrate", "[", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"njon", "^", "2"}], " ", "/", "2"}], ")"}], "  ", "barn", 
          "  ", "Q", " ", "2", " ", "keV", " ", "fMaxwell", " ", 
          "\[Sigma]val", " ", "vE", " ", "tau"}], "/.", "\[VeryThinSpace]", 
         RowBox[{"kBT", "\[Rule]", 
          RowBox[{"100", " ", "keV"}]}]}], "/.", "\[VeryThinSpace]", "vals"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"Ed", ",", "0", ",", "Edcutoff"}], "}"}]}], "]"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"tau", ",", "1", ",", "200"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.741787080807683*^9, 3.741787165026506*^9}, {
  3.7417872139614162`*^9, 3.7417872629542627`*^9}, {3.7418749065760937`*^9, 
  3.741874913517098*^9}},
 CellLabel->
  "In[397]:=",ExpressionUUID->"779dd216-b5c1-4b81-b005-c55325221843"],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ/VxKQ28CW63dqv59RnIbDB1ENV/mrp2/yh7GN1Jr
mLt6/i44P2h984aAfafh/CRx2w+/Z1+B8+csufTtp9ltOH+CdFPtUoOHcP6C
uerCMzuewPmhSrPVzTRewPmnzkYXv9j2Gs7nNVp5KZXjPZxf5ZMUcSzgI0J/
jFng/n+f4PyJ/zc8dVryBc6XXzLJcnbuNzhfZKmVeKTEDzg/ernnltfPfsL5
zLb/33Cs/Q3nC+lXr+8O+QvnFynFGT6W/w/ny+5slgtIY3CA8Vc95GaZ6ccI
5z8PTjdfbsQE50d8Waqfwc4M5xeJzmgXfofg70/JXVJ4lAXO3/NXlH/qDFYH
RHgX3VxUywbn28RvzEgOZkfoV18SzmfNAed/ssyaUifHCedHVglPW/gJwc+0
Lvi+7gYXnL9Wa4Ns/npuOH9h8uGJXxp54Hw72a7UlDReOJ+P1eRfmzUfnN+R
O/HbZCV+ON+U5dLm4F8Ivtenovg3aQJw/tlF10SW3ETws16t1tnqIgjnx3yK
Ktm9A8FXm/85aYmWEJzP+fjv5mdTEHzH5w9N5DiE4fzJTeYS64sR/L2HyhYp
3UXwrQ/3x3T7i8D5l6OkKn13Ifi9K7cde/wVwXf/ESRSZSgK5wMAJoRpiA==

        "]]},
      Annotation[#, "Charting`Private`Tag$112284#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Gs0lAkcBnBhXHJv5g05btMuoZ3b++Y6ep+VzoouLtsS1liGtQqhOmhV
S2e1aYuNthIjZ8rtuFdLqXGJNiu1SCRtUgi1SC5lamc//M9zfh+e58PfMizO
N0JZSUlpm+L+z7E16zhZaqkbhTdXPv3nHQfTg/5jpoWB9LvPdw1emeeg8LDD
4xFJNF15srj/lwUOknyKe9olKbRFqHsPucSB2FnkXS85TjNUDv2ZsczBY84N
3RrJebrLY6aWq8IFYfMqpkJSRot6H2Uc1udCYHUkv1xynU6flPLN7bjwrUqv
9r71Fz23ZGc6IOYizNB1+kNeLz3TM9kgO8/FBWn3/JL9IB10xKLs9/tcZJmk
pV7iDdNJapbG+1V5KMy3Zp479oI+Jui6SpnzsJOdZ22/bpyu7Iov4At56LgX
lDh+bZLW7L3PKw7gQUdQ2h2h8S+9nu4wIRN5SNkaFtDuPUOHr7nhu3xK0Q+2
95F9nKVDgzyeD5bxkP2p+qWbdI7OYWSZUG08mEt/c8qLmaeHzLsK7w7zwLrk
bLjLaJGekpQc2r/MQ1DxliuTo0u0QVZySYgxHyqun6Y0Kj7Qu1+p/ti0gY9V
3INVmV/L6RMl60scvflIYIfwR8w/0S2PPC3e7OHDtCHdzDtSCbI9jJmGDD7K
hrVUz21fgQfx13RapXyM+X3vUCxQhtEzy173Zj4C5i5xo9RVYHXF5u2TQcUe
cTaD+UYFWxatQ2oX+ZCJY6Txbaogi1osC5gCNMoJvdyzDPhdNTylzBEo/p0w
UJSqhgzHcA+ppwBCUU1UuJ860i29AoMjBJBZS/11XTRwOsWm3idNgFmn6JxD
ZpoYELbIZAUC7Ephnrk4q4lR8YK5e4MAP7jsXajsXwkNObuT0SdAhW21aVyV
FmbeTzwYmhbgYnhr9txP2tALiznM0SKx0fR4hDhSB5ucRpMbrUnoMqiPP7vo
wvXAh85QNxLHYrLnT7P1sHWt+h43EYkNqt11fu/1wLavCndOIeE5myCaitQH
p9aAUZ5D4l5RH0s6oI/tBdGzATUkoifK1191N4D9tMjRtJNE8Gzgvhv1BhDU
enWYvSJhJXkbJrVdBfHQDOMcg4LmiLxuNGcVvo2lzttYUPhybJgy02Bid1xM
yoKQwuk0B6OqRCbQ51Y36E/hZsuBIvYQE56Xu3MdEyi4tJ4KztzBQvRowO3u
kxR6Atckb7vOgveJg17ppRQ8XDPsbBtZeH17ddJ7hW+Zzw2p3WIhU14jjS+j
UPbinltTMwvtseNyUTmFtNiftMm7LAh9dlYLKyjw0sYlRv0sWK/mEvPVFH4t
vdY+8o6Fj5LnT6PqKSifWJvctMDChf5UrWcKJ8Vm2eUvseBkYOzo30BBTEZn
fSNnYV/ajuzN1ykIb5oG3lUlMCFu3MRupDDx4OjrSiaBPpszJYMyCqF1M5JM
gkBiGP+hbxOFvtwQ3yhDAgZ5nSs6FG4OdPzD0oSAl7ZKUH0zhbMvJo/ksAk0
v4nTyW2loHsngIz/jIDIWstZ+zaFo6VtL7dZEVgWXY5MV3hvrMRT3ZaAw99P
ZPFtFEa9teUjdgQeaiZNjSscTCZXNX1BIMGNaRzaTqGbGP0un0tA/2Dl5kcK
f7Xoy0rhE6io25Kw/Q6F/wAVyBjV
        "]]},
      Annotation[#, "Charting`Private`Tag$112284#2"]& ]}, {}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 15.480223597346246`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Exp[
        Part[#, 1]], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Exp[
        Part[#, 1]], 
       Exp[
        Part[#, 2]]}& )},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Log, Exp}]}, {
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Log, Exp}]}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None},
   PlotRange->NCache[{{0, 
       Log[200]}, {15.480223597346246`, 20.77854074763643}}, {{
      0, 5.298317366548036}, {15.480223597346246`, 20.77854074763643}}],
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->FrontEndValueCache[{
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledTicks[{Log, Exp}]}, {{{0., 
        FormBox["1", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
        FormBox["5", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {2.302585092994046, 
        FormBox["10", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {3.912023005428146, 
        FormBox["50", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {4.605170185988092, 
        FormBox["100", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.791759469228055, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.995732273553991, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.0943445622221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.248495242049359, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.382026634673881, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.499809670330265, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5.298317366548036, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5.703782474656201, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5.991464547107982, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.214608098422191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.396929655216146, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.551080335043404, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.684611727667927, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.802394763324311, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6.907755278982137, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.003065458786462, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.090076835776092, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.170119543449628, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.24422751560335, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.313220387090301, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7.3777589082278725`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}, {{15.424948470398375`, 
        FormBox[
         TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
           
           TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
            SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {16.11809565095832, 
        FormBox[
         TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
           
           TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
            SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {17.72753356339242, 
        FormBox[
         TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
           
           TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
            SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {18.420680743952367`, 
        FormBox[
         TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
           
           TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
            SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {20.030118656386467`, 
        FormBox[
         TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
           
           TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
            SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {20.72326583694641, 
        FormBox[
         TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
           
           TemplateBox[{"10", "9"}, "Superscript", SyntaxForm -> 
            SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {0.01, 
        0.}, {
         AbsoluteThickness[0.1]}}, {13.815510557964274`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14.508657738524219`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14.914122846632385`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {15.201804919084164`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {15.60727002719233, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {15.761420707019587`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {15.89495209964411, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16.012735135300492`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16.811242831518264`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {17.216707939626428`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {17.50439001207821, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {17.909855120186375`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.064005800013632`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.197537192638155`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18.31532022829454, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {19.11382792451231, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {19.519293032620475`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {19.806975105072254`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20.21244021318042, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20.36659089300768, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20.5001222856322, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {20.617905321288585`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {21.416413017506358`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {21.82187812561452, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22.1095601980663, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22.33270374938051, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22.515025306174465`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22.669175986001726`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22.80270737862625, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22.920490414282632`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {23.025850929940457`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.741874914746126*^9, 3.742037987945043*^9, 
  3.787999279066893*^9},
 CellLabel->"Out[397]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"8b9d7fa3-76a5-42bb-a432-99cda91b5462"]
}, Open  ]],

Cell[TextData[{
 "\nVi ser att vi m\[ARing]ste h\[ARing]lla ig\[ARing]ng fusionen i \[Tau] > \
10 sekunder f\[ODoubleDot]r att precis b\[ODoubleDot]rja f\[ARing] ut energi.\
\nSnabbkoll (a la Enrico Fermi) att det st\[ADoubleDot]mmer: enligt ovan \
\[ADoubleDot]r reaktiviteten <\[Sigma] v>  vid 100 keV runt 2 x 10^(-23) \
m^3/s. Energifaktorerna i kriteriet \[ADoubleDot]r 6 kBT/Q = 600 keV/4 MeV ~ \
0.2 s\[ARing] produkten n \[Tau] m\[ARing]ste vara minst 0.2/(0.2 x 10^(-22)) \
= 10^22 s/m^3. Med n = 10^21 partiklar/m^3 s\[ARing] \[ADoubleDot]r Lawsons \
kriterium uppfyllt f\[ODoubleDot]r \[Tau] > 10 sekunder. Det ser vi i \
plotten. \n\nObservera: f\[ODoubleDot]r precis \[Tau] = 10 s \[ADoubleDot]r \
det fortfarande meningsl\[ODoubleDot]st att bygga ett kraftverk: det \
g\[ARing]r d\[ARing] \[ARing]t lika mycket energi att uppr\[ADoubleDot]tth\
\[ARing]lla temperaturen som energin som kraftverket producerar fr\[ARing]n \
fusion. D\[ADoubleDot]rf\[ODoubleDot]r \[ADoubleDot]r Lawsons kriterium en \
olikhet: \[Tau] m\[ARing]ste vara en bra bit \[ODoubleDot]ver 10 sekunder f\
\[ODoubleDot]r att elproduktion fr\[ARing]n k\[ADoubleDot]rnfusion skall vara \
meningsfullt. ITER provar deuterium-tritium, som har st\[ODoubleDot]rre Q och \
beh\[ODoubleDot]ver n\[ARing]got l\[ADoubleDot]gre temperatur, och de skall \
visa att de kan h\[ARing]lla ig\[ARing]ng reaktionen \[ODoubleDot]ver 10 \
minuter. \n\n(Kommentar: Lawson-kriteriet ges oftast som n \[Tau] > 12 kB \
T/(<\[Sigma] v> Q), skiljer med en faktor 2 j\[ADoubleDot]mf\[ODoubleDot]rt \
med ovan pga. diskussionen om n^2/2 kontra n^2/4. Dessutom \
anv\[ADoubleDot]nds ofta ett nyare kriterium d\[ADoubleDot]r man r\
\[ADoubleDot]knar ut en produkt ocks\[ARing] med temperaturen, ist\
\[ADoubleDot]llet f\[ODoubleDot]r att betrakta en fix temperatur som h\
\[ADoubleDot]r. ITER har t\[ADoubleDot]nkt uppn\[ARing] \[ADoubleDot]ven det \
kriteriet, se ",
 StyleBox["iter.org",
  FontSlant->"Italic"],
 ".)"
}], "Text",
 CellChangeTimes->{{3.7414183283447857`*^9, 3.7414183377438107`*^9}, {
   3.741418388940918*^9, 3.741418462570117*^9}, {3.74141852350233*^9, 
   3.74141854063828*^9}, {3.74145236421882*^9, 3.741452369602613*^9}, 
   3.741712478978737*^9, {3.741787303702723*^9, 3.7417873152470617`*^9}, {
   3.741788394898682*^9, 3.7417884223494062`*^9}, {3.7417884736560698`*^9, 
   3.741788503211014*^9}, {3.741788719297174*^9, 3.741788756996253*^9}, {
   3.7417887901075897`*^9, 3.7417890051728477`*^9}, {3.7417890718635483`*^9, 
   3.741789336412808*^9}, {3.741874465391086*^9, 3.7418745796113873`*^9}, {
   3.741874649729548*^9, 3.741874681287616*^9}, {3.788331995344079*^9, 
   3.78833204662685*^9}, {3.788332078363372*^9, 
   3.7883320914003077`*^9}},ExpressionUUID->"ef6a6e81-0743-4a0c-a4d3-\
4d9710a83aa0"]
},
WindowSize->{1082, 851},
WindowMargins->{{126, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
Magnification:>1.5 Inherited,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 276, 5, 62, "Text",ExpressionUUID->"4d461007-e9a4-438a-91d1-eb977c53216e"],
Cell[837, 27, 2916, 44, 640, "Text",ExpressionUUID->"8d59f7de-516a-46aa-8d76-cb7dd31698a8"],
Cell[3756, 73, 1818, 39, 140, "Input",ExpressionUUID->"5bfde129-298c-47ee-8fa9-d6dd4858e203"],
Cell[5577, 114, 1618, 26, 364, "Text",ExpressionUUID->"83ef0966-07ed-450c-a07f-a89a947a31d0"],
Cell[CellGroupData[{
Cell[7220, 144, 3274, 75, 171, "Input",ExpressionUUID->"7b919e3f-2b33-46cf-9743-bdda4832251e"],
Cell[10497, 221, 270, 6, 71, "Output",ExpressionUUID->"960208ba-efb6-49ba-a30b-e6819b5021b8"]
}, Open  ]],
Cell[10782, 230, 568, 11, 88, "Text",ExpressionUUID->"7c84d2a5-062c-4036-a723-ead94f4f419d"],
Cell[CellGroupData[{
Cell[11375, 245, 1240, 28, 46, "Input",ExpressionUUID->"2cd1e7b2-dce9-401a-bf32-d1ad539725ef"],
Cell[12618, 275, 1272, 19, 47, "Output",ExpressionUUID->"23372146-8b39-42cc-8922-ddad7db9db33"]
}, Open  ]],
Cell[13905, 297, 1014, 19, 191, "Text",ExpressionUUID->"9eeb8bd1-bf61-459d-86cc-5e9a6b8ef289"],
Cell[14922, 318, 798, 13, 88, "Text",ExpressionUUID->"ac30f270-c8fc-4262-aab2-a77cf2f76e0d"],
Cell[CellGroupData[{
Cell[15745, 335, 3696, 84, 233, "Input",ExpressionUUID->"49bd51c1-2a0d-4a17-9b3c-5f244dbe8005"],
Cell[19444, 421, 2983, 46, 94, "Output",ExpressionUUID->"3c1f34bd-ee7a-42e3-97e7-3224d3f8b302"],
Cell[22430, 469, 11770, 220, 345, "Output",ExpressionUUID->"68b5d49e-7bbc-42e7-a3be-f4099cace500"],
Cell[34203, 691, 17263, 324, 345, "Output",ExpressionUUID->"28c97024-1b10-4902-870a-db0c62d8a678"]
}, Open  ]],
Cell[51481, 1018, 594, 10, 88, "Text",ExpressionUUID->"29851d8d-41fe-4985-a22a-2c597ddedba6"],
Cell[CellGroupData[{
Cell[52100, 1032, 421, 9, 46, "Input",ExpressionUUID->"7ac00232-0ab4-44c5-b6e5-1c36e951dbb5"],
Cell[52524, 1043, 1086, 20, 47, "Output",ExpressionUUID->"3e2c5c39-d4c2-40f8-9118-aa2433c6f24f"]
}, Open  ]],
Cell[53625, 1066, 2395, 39, 467, "Text",ExpressionUUID->"9bf349d6-5cc3-4c0d-99cb-a3937742fea2"],
Cell[CellGroupData[{
Cell[56045, 1109, 605, 14, 46, "Input",ExpressionUUID->"a767461a-2c74-4386-8009-ab60987f141d"],
Cell[56653, 1125, 1213, 22, 75, "Output",ExpressionUUID->"956f49ac-3ddf-466f-b4a6-c390d4ad2f83"]
}, Open  ]],
Cell[57881, 1150, 379, 8, 88, "Text",ExpressionUUID->"76f2740b-dc9f-48b9-99c1-930466d869c8"],
Cell[CellGroupData[{
Cell[58285, 1162, 927, 27, 109, "Input",ExpressionUUID->"1fe05d76-8095-4074-9fb9-f380c272d74b"],
Cell[59215, 1191, 1281, 27, 95, "Output",ExpressionUUID->"d465dd1b-1d52-499f-9b17-1797e1501bd5"]
}, Open  ]],
Cell[60511, 1221, 436, 9, 88, "Text",ExpressionUUID->"3c19d77e-2c04-4c97-867e-a4c63d9d89a7"],
Cell[CellGroupData[{
Cell[60972, 1234, 3224, 63, 140, "Input",ExpressionUUID->"f7e0b38b-b4cc-414a-a025-5c265f48cb22"],
Cell[64199, 1299, 45802, 770, 364, "Output",ExpressionUUID->"15d51d58-46ab-4c36-a5f6-6b92aae7c2ae"],
Cell[110004, 2071, 2527, 36, 47, "Output",ExpressionUUID->"6bd6d82e-ba8f-4efa-9eee-7274247ef427"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112568, 2112, 880, 23, 78, "Input",ExpressionUUID->"87415ee8-81c7-4586-a218-e057438811fb"],
Cell[113451, 2137, 2730, 41, 53, "Output",ExpressionUUID->"726ce63d-8c51-45b5-b842-51828c2888fd"],
Cell[116184, 2180, 2734, 41, 53, "Output",ExpressionUUID->"0e8d9e3f-f485-466f-ab30-e36bca6ed11e"]
}, Open  ]],
Cell[118933, 2224, 536, 10, 122, "Text",ExpressionUUID->"3afdd712-9ca2-46ad-8632-2f97e0e8932e"],
Cell[CellGroupData[{
Cell[119494, 2238, 1881, 38, 140, "Input",ExpressionUUID->"424683d1-862e-4222-845f-c8dc6491a937"],
Cell[121378, 2278, 64902, 1128, 315, "Output",ExpressionUUID->"4afc12d7-c31f-472c-990a-b6e9cab9829e"]
}, Open  ]],
Cell[186295, 3409, 597, 10, 122, "Text",ExpressionUUID->"fc0ad79f-13a7-4a8f-9718-e212fd80d05f"],
Cell[CellGroupData[{
Cell[186917, 3423, 513, 14, 109, "Input",ExpressionUUID->"18c2061e-021d-44f8-ab82-d8141b2a32c3"],
Cell[187433, 3439, 1011, 19, 47, "Output",ExpressionUUID->"1903f33f-247c-4f04-82a6-de372590abe6"],
Cell[188447, 3460, 1037, 19, 53, "Output",ExpressionUUID->"0c85bd81-43ba-495c-aa95-a2746bac0f04"]
}, Open  ]],
Cell[189499, 3482, 1250, 22, 260, "Text",ExpressionUUID->"25724319-cb84-4c5f-91b0-004ef1ab9131"],
Cell[CellGroupData[{
Cell[190774, 3508, 406, 9, 78, "Input",ExpressionUUID->"d31add2c-17bc-4c8e-a94b-32755b3631b0"],
Cell[191183, 3519, 1071, 19, 53, "Output",ExpressionUUID->"c9d2bfbc-3782-4ee1-b100-8021746385ff"]
}, Open  ]],
Cell[192269, 3541, 1348, 21, 191, "Text",ExpressionUUID->"c5b50b98-ccfc-45b2-ab6e-731da259f4f9"],
Cell[CellGroupData[{
Cell[193642, 3566, 1477, 27, 78, "Input",ExpressionUUID->"3d620c3e-f5ff-4f5d-aa88-ffdde57aacec"],
Cell[195122, 3595, 1411, 21, 50, "Output",ExpressionUUID->"be50cdc6-4a40-411a-b2b3-8b57152e3a5e"]
}, Open  ]],
Cell[196548, 3619, 1457, 23, 329, "Text",ExpressionUUID->"09bb1e00-a86f-4663-92b7-a62328e26241"],
Cell[CellGroupData[{
Cell[198030, 3646, 1771, 43, 78, "Input",ExpressionUUID->"aded8900-dcf9-40a3-978e-40f2780d01b1"],
Cell[199804, 3691, 1510, 23, 50, "Output",ExpressionUUID->"4ca6bef6-b11e-459d-b045-9463ce841727"],
Cell[201317, 3716, 1547, 25, 59, "Output",ExpressionUUID->"7fa691a3-1603-4b97-9035-c386d7b95caf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[202901, 3746, 1714, 36, 109, "Input",ExpressionUUID->"3c2de956-0735-4f56-a822-2875d5ecf32a"],
Cell[204618, 3784, 23025, 455, 349, "Output",ExpressionUUID->"bc8eb2e8-5293-4dfd-b0d3-7714ade732cc"]
}, Open  ]],
Cell[227658, 4242, 1615, 27, 329, "Text",ExpressionUUID->"10a88a98-b22d-4e49-8200-852b50d9251f"],
Cell[CellGroupData[{
Cell[229298, 4273, 1097, 28, 140, "Input",ExpressionUUID->"779dd216-b5c1-4b81-b005-c55325221843"],
Cell[230398, 4303, 26257, 503, 341, 16288, 339, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"8b9d7fa3-76a5-42bb-a432-99cda91b5462"]
}, Open  ]],
Cell[256670, 4809, 2784, 42, 605, "Text",ExpressionUUID->"ef6a6e81-0743-4a0c-a4d3-4d9710a83aa0"]
}
]
*)

